@@ -10,10 +10,10 @@ import math
 import re
 import sys
 import threading
-import time
 from contextlib import suppress
 from decimal import Decimal
 from queue import Queue
+from time import sleep as time_sleep
 from typing import Any, Optional, Type, Union
 from urllib.parse import urlparse
 from warnings import warn
@@ -67,7 +67,8 @@ from pywikibot.logging import (
     warning,
 )
 from pywikibot.site import APISite, BaseSite, DataSite
-from pywikibot.tools import classproperty, normalize_username
+from pywikibot.time import Timestamp
+from pywikibot.tools import normalize_username, PYTHON_VERSION
 
 
 ItemPageStrNoneType = Union[str, 'ItemPage', None]
@@ -77,12 +78,13 @@ __all__ = (
     '__copyright__', '__description__', '__download_url__', '__license__',
     '__maintainer__', '__maintainer_email__', '__name__', '__url__',
     '__version__',
-    'Bot', 'calledModuleName', 'Category', 'Claim', 'Coordinate', 'critical',
-    'CurrentPageBot', 'debug', 'error', 'exception', 'FilePage', 'handle_args',
-    'html2unicode', 'info', 'input', 'input_choice', 'input_yn', 'ItemPage',
-    'LexemeForm', 'LexemePage', 'LexemeSense', 'Link', 'log', 'MediaInfo',
-    'output', 'Page', 'PropertyPage', 'showDiff', 'show_help', 'Site',
-    'SiteLink', 'stdout', 'Timestamp', 'translate', 'ui', 'url2unicode',
+    'async_manager', 'async_request', 'Bot', 'calledModuleName', 'Category',
+    'Claim', 'Coordinate', 'critical', 'CurrentPageBot', 'debug', 'error',
+    'exception', 'FilePage', 'handle_args', 'html2unicode', 'info', 'input',
+    'input_choice', 'input_yn', 'ItemPage', 'LexemeForm', 'LexemePage',
+    'LexemeSense', 'Link', 'log', 'MediaInfo', 'output', 'Page',
+    'PropertyPage', 'showDiff', 'show_help', 'Site', 'SiteLink', 'sleep',
+    'stdout', 'stopme', 'Timestamp', 'translate', 'ui', 'url2unicode',
     'User', 'warning', 'WbGeoShape', 'WbMonolingualText', 'WbQuantity',
     'WbTabularData', 'WbTime', 'WbUnknown', 'WikidataBot',
 )
@@ -93,111 +95,13 @@ if not hasattr(sys.modules[__name__], 'argvu'):
     argvu = []  # type: List[str]
 
 
-class Timestamp(datetime.datetime):
-
-    """Class for handling MediaWiki timestamps.
-
-    This inherits from datetime.datetime, so it can use all of the methods
-    and operations of a datetime object. To ensure that the results of any
-    operation are also a Timestamp object, be sure to use only Timestamp
-    objects (and datetime.timedeltas) in any operation.
-
-    Use Timestamp.fromISOformat() and Timestamp.fromtimestampformat() to
-    create Timestamp objects from MediaWiki string formats.
-    As these constructors are typically used to create objects using data
-    passed provided by site and page methods, some of which return a Timestamp
-    when previously they returned a MediaWiki string representation, these
-    methods also accept a Timestamp object, in which case they return a clone.
-
-    Use Site.server_time() for the current time; this is more reliable
-    than using Timestamp.utcnow().
-    """
-
-    mediawikiTSFormat = '%Y%m%d%H%M%S'
-    _ISO8601Format_new = '{0:+05d}-{1:02d}-{2:02d}T{3:02d}:{4:02d}:{5:02d}Z'
-
-    def clone(self) -> datetime.datetime:
-        """Clone this instance."""
-        return self.replace(microsecond=self.microsecond)
-
-    @classproperty
-    def ISO8601Format(cls: Type['Timestamp']) -> str:
-        """ISO8601 format string class property for compatibility purpose."""
-        return cls._ISO8601Format()
-
-    @classmethod
-    def _ISO8601Format(cls: Type['Timestamp'], sep: str = 'T') -> str:
-        """ISO8601 format string.
-
-        :param sep: one-character separator, placed between the date and time
-        :return: ISO8601 format string
-        """
-        assert len(sep) == 1
-        return '%Y-%m-%d{}%H:%M:%SZ'.format(sep)
-
-    @classmethod
-    def fromISOformat(cls: Type['Timestamp'], ts: Union[str, 'Timestamp'],
-                      sep: str = 'T') -> 'Timestamp':
-        """Convert an ISO 8601 timestamp to a Timestamp object.
-
-        :param ts: ISO 8601 timestamp or a Timestamp object already
-        :param sep: one-character separator, placed between the date and time
-        :return: Timestamp object
-        """
-        # If inadvertently passed a Timestamp object, use replace()
-        # to create a clone.
-        if isinstance(ts, cls):
-            return ts.clone()
-        return cls.strptime(ts, cls._ISO8601Format(sep))
-
-    @classmethod
-    def fromtimestampformat(cls: Type['Timestamp'], ts: Union[str, 'Timestamp']
-                            ) -> 'Timestamp':
-        """Convert a MediaWiki internal timestamp to a Timestamp object."""
-        # If inadvertently passed a Timestamp object, use replace()
-        # to create a clone.
-        if isinstance(ts, cls):
-            return ts.clone()
-        if len(ts) == 8:  # year, month and day are given only
-            ts += '000'
-        return cls.strptime(ts, cls.mediawikiTSFormat)
-
-    def isoformat(self, sep: str = 'T') -> str:  # type: ignore[override]
-        """
-        Convert object to an ISO 8601 timestamp accepted by MediaWiki.
-
-        datetime.datetime.isoformat does not postfix the ISO formatted date
-        with a 'Z' unless a timezone is included, which causes MediaWiki
-        ~1.19 and earlier to fail.
-        """
-        return self.strftime(self._ISO8601Format(sep))
-
-    def totimestampformat(self) -> str:
-        """Convert object to a MediaWiki internal timestamp."""
-        return self.strftime(self.mediawikiTSFormat)
-
-    def __str__(self) -> str:
-        """Return a string format recognized by the API."""
-        return self.isoformat()
-
-    def __add__(self, other: datetime.timedelta) -> 'Timestamp':
-        """Perform addition, returning a Timestamp instead of datetime."""
-        newdt = super().__add__(other)
-        if isinstance(newdt, datetime.datetime):
-            return Timestamp(newdt.year, newdt.month, newdt.day, newdt.hour,
-                             newdt.minute, newdt.second, newdt.microsecond,
-                             newdt.tzinfo)
-        return newdt
-
-    def __sub__(self, other: datetime.timedelta  # type: ignore[override]
-                ) -> 'Timestamp':
-        """Perform subtraction, returning a Timestamp instead of datetime."""
-        newdt = super().__sub__(other)
-        if isinstance(newdt, datetime.datetime):
-            return Timestamp(newdt.year, newdt.month, newdt.day, newdt.hour,
-                             newdt.minute, newdt.second, newdt.microsecond,
-                             newdt.tzinfo)
-        return newdt
+if PYTHON_VERSION < (3, 6):
+    warn("""
+Python {version} will be dropped with release 8.0 soon.
+It is recommended to use Python 3.6 or above.
+See T301908 for further information.
+""".format(version=sys.version.split(maxsplit=1)[0]),
+         FutureWarning)  # adjust this line no in utils.execute()
 
 
 class Coordinate(_WbRepresentation):
@@ -837,7 +741,7 @@ class _WbDataPage(_WbRepresentation):
     """
     A Wikibase representation for data pages.
 
-    A temporary implementation until T162336 has been resolved.
+    A temporary implementation until :phab:`T162336` has been resolved.
 
     Note that this class cannot be used directly
     """
@@ -1113,7 +1017,7 @@ def Site(code: Optional[str] = None,
 
     Override default family::
 
-        site = pywikibot.Site(family='wikisource')
+        site = pywikibot.Site(fam='wikisource')
 
     Setting a specific site::
 
@@ -1123,8 +1027,8 @@ def Site(code: Optional[str] = None,
 
         site = pywikibot.Site('wikisource:fr')
 
-    :Note: An already created site is cached an a new variable points to
-        the same object if interface, family, code and user are equal:
+    .. note:: An already created site is cached an a new variable points
+       to the same object if interface, family, code and user are equal:
 
     >>> import pywikibot
     >>> site_1 = pywikibot.Site('wikisource:fr')
@@ -1134,11 +1038,15 @@ def Site(code: Optional[str] = None,
     >>> site_1
     APISite("fr", "wikisource")
 
-    ``APISite`` is the default interface. Refer :py:obj:`pywikibot.site` for
-    other interface types.
+    :class:`APISite<pywikibot.site._apisite.APISite>` is the default
+    interface. Refer :py:obj:`pywikibot.site` for other interface types.
 
-    **Never create a site object via interface class directly.**
-    Always use this factory method.
+    .. warning:: Never create a site object via interface class directly.
+       Always use this factory method.
+
+    .. versionchanged:: 7.3
+       Short creation if site code is equal to family name like
+       `Site('commons')`, `Site('meta')` or `Site('wikidata')`.
 
     :param code: language code (override config.mylang)
         code may also be a sitename like 'wikipedia:test'
@@ -1167,6 +1075,9 @@ def Site(code: Optional[str] = None,
                 'should be provided')
         fam, _, code = code.partition(':')
     else:
+        if not fam:  # try code as family
+            with suppress(exceptions.UnknownFamilyError):
+                fam = Family.load(code)
         # Fallback to config defaults
         code = code or _config.mylang
         fam = fam or _config.family
@@ -1259,7 +1170,7 @@ def sleep(secs: int) -> None:
     """
     if secs >= 30:
         stopme()
-    time.sleep(secs)
+    time_sleep(secs)
 
 
 def stopme() -> None:
@@ -1303,38 +1214,44 @@ def _flush(stop: bool = True) -> None:
                'Estimated time remaining: {sec}<<default>>'
                .format(num=num, sec=sec))
 
+    exit_queue = None
     if _putthread is not threading.current_thread():
-        while (_putthread.is_alive()
-               and (page_put_queue.qsize() > 0
-                    or page_put_queue_busy.qsize() > 0)):
+        while _putthread.is_alive() and not (page_put_queue.empty()
+                                             and page_put_queue_busy.empty()):
             try:
                 _putthread.join(1)
             except KeyboardInterrupt:
-                if input_yn('There are {} pages remaining in the queue. '
-                            'Estimated time remaining: {}\nReally exit?'
-                            .format(*remaining()),
-                            default=False, automatic_quit=False):
-                    # delete the put queue
-                    with page_put_queue.mutex:
-                        page_put_queue.all_tasks_done.notify_all()
-                        page_put_queue.queue.clear()
-                        page_put_queue.not_full.notify_all()
-                    break
+                exit_queue = input_yn(
+                    'There are {} pages remaining in the queue. Estimated '
+                    'time remaining: {}\nReally exit?'.format(*remaining()),
+                    default=False, automatic_quit=False)
+                break
+
+    if exit_queue is False:
+        # handle the queue when _putthread is stopped after KeyboardInterrupt
+        with suppress(KeyboardInterrupt):
+            async_manager(block=False)
+
+    if not stop:
+        # delete the put queue
+        with page_put_queue.mutex:
+            page_put_queue.all_tasks_done.notify_all()
+            page_put_queue.queue.clear()
+            page_put_queue.not_full.notify_all()
 
     # only need one drop() call because all throttles use the same global pid
-    with suppress(IndexError):
-        list(_sites.values())[0].throttle.drop()
+    with suppress(KeyError):
+        _sites.popitem()[1].throttle.drop()
         log('Dropped throttle(s).')
 
 
-atexit.register(_flush)
-
-
 # Create a separate thread for asynchronous page saves (and other requests)
-def async_manager() -> None:
+def async_manager(block=True) -> None:
     """Daemon; take requests from the queue and execute them in background."""
     while True:
-        (request, args, kwargs) = page_put_queue.get()
+        if not block and page_put_queue.empty():
+            break
+        (request, args, kwargs) = page_put_queue.get(block)
         page_put_queue_busy.put(None)
         if request is None:
             break
@@ -1359,3 +1276,4 @@ page_put_queue_busy = Queue(_config.max_queue_size)  # type: Queue
 _putthread = threading.Thread(target=async_manager,
                               name='Put-Thread',  # for debugging purposes
                               daemon=True)
+atexit.register(_flush)
