@@ -98,7 +98,7 @@ import time
 import warnings
 import webbrowser
 from collections import Counter
-from collections.abc import Generator
+from collections.abc import Container, Generator
 from contextlib import closing
 from functools import wraps
 from importlib import import_module
@@ -195,20 +195,22 @@ GLOBAL OPTIONS
 ==============
 (Global arguments available for all bots)
 
--dir:PATH         Read the bot's configuration data from directory given by
-                  PATH, instead of from the default directory.
+-dir:PATH         Read the bot's configuration data from directory given
+                  by PATH, instead of from the default directory.
 
--lang:xx          Set the language of the wiki you want to work on, overriding
-                  the configuration in user-config.py. xx should be the
-                  site code.
+-config:xyn       The user config filename. Default is user-config.py.
+
+-lang:xx          Set the language of the wiki you want to work on,
+                  overriding the configuration in user config file.
+                  xx should be the site code.
 
 -family:xyz       Set the family of the wiki you want to work on, e.g.
-                  wikipedia, wiktionary, wikivoyage, ...
-                  This will override the configuration in user-config.py.
+                  wikipedia, wiktionary, wikivoyage, ... This will
+                  override the configuration in user config file.
 
 -site:xyz:xx      Set the wiki site you want to work on, e.g.
-                  wikipedia:test, wiktionary:de, wikivoyage:en, ...
-                  This will override the configuration in user-config.py.
+                  wikipedia:test, wiktionary:de, wikivoyage:en, ... This
+                  will override the configuration in user config file.
 
 -user:xyz         Log in as user 'xyz' instead of the default username.
 
@@ -226,24 +228,24 @@ GLOBAL OPTIONS
 
 -nolog            Disable the log file (if it is enabled by default).
 
--maxlag           Sets a new maxlag parameter to a number of seconds. Defer bot
-                  edits during periods of database server lag. Default is set
-                  by config.py
+-maxlag           Sets a new maxlag parameter to a number of seconds.
+                  Defer bot edits during periods of database server lag.
+                  Default is set by config.py
 
--putthrottle:n    Set the minimum time (in seconds) the bot will wait between
--pt:n             saving pages.
+-putthrottle:n    Set the minimum time (in seconds) the bot will wait
+-pt:n             between saving pages.
 -put_throttle:n
 
--debug:item       Enable the log file and include extensive debugging data
--debug            for component "item" (for all components if the second form
-                  is used).
+-debug:item       Enable the log file and include extensive debugging
+-debug            data for component "item" (for all components if the
+                  second form is used).
 
 -verbose          Have the bot provide additional console output that may be
 -v                useful in debugging.
 
 -cosmeticchanges  Toggles the cosmetic_changes setting made in config.py
--cc               or user-config.py to its inverse and overrules it. All
-                  other settings and restrictions are untouched. The
+-cc               or user config file to its inverse and overrules it.
+                  All other settings and restrictions are untouched. The
                   setting may also be given directly like `-cc:True`;
                   accepted values for the option are `1`, `yes`, `true`,
                   `on`, `y`, `t` for True and `0`, `no`, `false`, `off`,
@@ -255,8 +257,8 @@ GLOBAL OPTIONS
                   An integer or float value may be given to simulate a
                   processing time; the bot just waits for given seconds.
 
--<config var>:n   You may use all given numeric config variables as option and
-                  modify it with command line.
+-<config var>:n   You may use all given numeric config variables as
+                  option and modify it with command line.
 
 """
 
@@ -293,12 +295,12 @@ def set_interface(module_name: str) -> None:
     pywikibot.argvu = ui.argvu()
 
     # re-initialize
-
     if _handlers_initialized:
+        _handlers_initialized.clear()
         init_handlers()
 
 
-_handlers_initialized = False
+_handlers_initialized = []  # we can have a script and the script wrapper
 
 
 def handler_namer(name: str) -> str:
@@ -355,8 +357,6 @@ def init_handlers() -> None:
       Different logfiles are used if multiple processes of the same
       script are running.
     """
-    global _handlers_initialized
-
     module_name = calledModuleName()
     if not module_name:
         module_name = 'terminal-interface'
@@ -372,6 +372,8 @@ def init_handlers() -> None:
     # for prompts requiring user response
 
     root_logger = logging.getLogger('pywiki')
+    if root_logger.hasHandlers() and module_name in _handlers_initialized:
+        return
     root_logger.setLevel(DEBUG + 1)  # all records except DEBUG go to logger
 
     warnings_logger = logging.getLogger('py.warnings')
@@ -387,7 +389,10 @@ def init_handlers() -> None:
             warnings.filterwarnings('module')
         warnings.filterwarnings('once', category=FutureWarning)
 
-    root_logger.handlers = []  # remove any old handlers
+    for handler in root_logger.handlers:
+        handler.close()
+    root_logger.handlers.clear()  # remove any old handlers
+    root_logger.propagate = False  # T281643
 
     # configure handler(s) for display to user interface
     assert ui is not None
@@ -412,7 +417,7 @@ def init_handlers() -> None:
         # give up infinite rotating file handler with logfilecount of -1;
         # set it to 999 and use the standard implementation
         max_count = config.logfilecount
-        if max_count == -1:
+        if max_count == -1:  # pragma: no cover
             max_count = 999
             issue_deprecation_warning('config.logfilecount with value -1',
                                       'any positive number',
@@ -447,7 +452,7 @@ def init_handlers() -> None:
 
         warnings_logger.addHandler(file_handler)
 
-    _handlers_initialized = True
+    _handlers_initialized.append(module_name)
 
     writelogheader()
 
@@ -482,8 +487,6 @@ def writelogheader() -> None:
     # config file dir
     log('CONFIG FILE DIR: {}'.format(pywikibot.config.base_dir))
 
-    all_modules = sys.modules.keys()
-
     # These are the main dependencies of pywikibot.
     check_package_list = [
         'requests',
@@ -492,7 +495,7 @@ def writelogheader() -> None:
 
     # report all imported packages
     if config.verbose_output:
-        check_package_list += all_modules
+        check_package_list += sys.modules
 
     log('PACKAGES:')
     packages = version.package_versions(check_package_list)
@@ -848,18 +851,35 @@ def calledModuleName() -> str:
 def handle_args(args: Optional[Iterable[str]] = None,
                 do_help: bool = True) -> List[str]:
     """
-    Handle standard command line arguments, and return the rest as a list.
+    Handle global command line arguments and return the rest as a list.
 
-    Takes the command line arguments as strings, processes all global
-    parameters such as -lang or -log, initialises the logging layer,
-    which emits startup information into log at level 'verbose'.
+    Takes the command line arguments as strings, processes all
+    :ref:`global parameters<global options>` such as ``-lang`` or
+    ``-log``, initialises the logging layer, which emits startup
+    information into log at level 'verbose'. This function makes sure
+    that global arguments are applied first, regardless of the order in
+    which the arguments were given. ``args`` may be passed as an
+    argument, thereby overriding ``sys.argv``.
 
-    This makes sure that global arguments are applied first,
-    regardless of the order in which the arguments were given.
+    >>> local_args = pywikibot.handle_args()  # sys.argv is used
+    >>> local_args  # doctest: +SKIP
+    []
+    >>> local_args = pywikibot.handle_args(['-simulate', '-myoption'])
+    >>> local_args  # global optons are handled, show the remaining
+    ['-myoption']
+    >>> for arg in local_args: pass  # do whatever is wanted with local_args
 
-    args may be passed as an argument, thereby overriding sys.argv
+    .. versionchanged:: 5.2
+       *-site* global option was added
+    .. versionchanged:: 7.1
+       *-cosmetic_changes* and *-cc* may be set directly instead of
+       toggling the value. Refer :func:`tools.strtobool` for valid values.
+    .. versionchanged:: 7.7
+       *-config* global option was added.
 
-    :param args: Command line arguments
+    :param args: Command line arguments. If None,
+        :meth:`pywikibot.argvu<userinterfaces._interface_base.ABUIC.argvu>`
+        is used which is a copy of ``sys.argv``
     :param do_help: Handle parameter '-help' to show help and invoke sys.exit
     :return: list of arguments not recognised globally
     """
@@ -885,7 +905,8 @@ def handle_args(args: Optional[Iterable[str]] = None,
         option, _, value = arg.partition(':')
         if do_help_val is not False and option == '-help':
             do_help_val = value or True
-        elif option == '-dir':
+        # these are handled by config.py
+        elif option in ('-config', '-dir'):
             pass
         elif option == '-site':
             config.family, config.mylang = value.split(':')
@@ -963,8 +984,10 @@ def handle_args(args: Optional[Iterable[str]] = None,
         try:
             pywikibot.Site()
         except (UnknownFamilyError, UnknownSiteError):
-            pywikibot.exception()
+            pywikibot.exception(exc_info=False)
             sys.exit(1)
+        if calledModuleName() == 'pwb':
+            pywikibot._sites.clear()
 
     if username:
         config.usernames[config.family][config.mylang] = username
@@ -1167,18 +1190,19 @@ class OptionHandler:
 
     >>> 'Option opt.{foo} is {bar}'.format_map(bot.opt)
     'Option opt.bar is 4711'
+
+    .. warning:: You must not access bot options as an attribute if the
+       keyword is a :python:`dict method<library/stdtypes.html#dict.clear>`.
     """
 
-    # Handler configuration.
-    # Only the keys of the dict can be passed as init options
-    # The values are the default values
-    # Overwrite this in subclasses!
-
     available_options = {}  # type: Dict[str, Any]
+    """ Handler configuration attribute.
+    Only the keys of the dict can be passed as `__init__` options.
+    The values are the default values. Overwrite this in subclasses!
+    """
 
     def __init__(self, **kwargs: Any) -> None:
-        """
-        Only accept options defined in available_options.
+        """Only accept options defined in available_options.
 
         :param kwargs: bot options
         """
@@ -1201,8 +1225,10 @@ class OptionHandler:
 
 class BaseBot(OptionHandler):
 
-    """
-    Generic Bot to be subclassed.
+    """Generic Bot to be subclassed.
+
+    Only accepts `generator` and options defined in
+    :attr:`available_options`.
 
     This class provides a :meth:`run` method for basic processing of a
     generator one page at a time.
@@ -1213,20 +1239,19 @@ class BaseBot(OptionHandler):
     implemented by subclasses.
 
     Each item processed by :meth:`treat` must be a
-    :class:`pywikibot.page.BasePage` type. Use :meth:`init_page` to
+    :class:`page.BasePage` type. Use :meth:`init_page` to
     upcast the type. To enable other types, set
     :attr:`BaseBot.treat_page_type` to an appropriate type; your bot
     should derive from :class:`BaseBot` in that case and handle site
     properties.
 
     If the subclass does not set a generator, or does not override
-    :meth:`treat` or :meth:`run`, NotImplementedError is raised.
+    :meth:`treat` or :meth:`run`, `NotImplementedError` is raised.
 
     For bot options handling refer :class:`OptionHandler` class above.
 
     .. versionchanged:: 7.0
-       A counter attribute is provided which is a `collections.Counter`;
-       The default counters are 'read', 'write' and 'skip'.
+       A :attr:`counter` instance variable is provided.
     """
 
     use_disambigs = None  # type: Optional[bool]
@@ -1240,23 +1265,28 @@ class BaseBot(OptionHandler):
     use_redirects = None  # type: Optional[bool]
     """Attribute to determine whether to use redirect pages. Set it to
     True to use redirects only, set it to False to skip redirects. If
-    None both are processed.
+    None both are processed. For example to create a RedirectBot you may
+    define:
+
+    .. code-block:: python
+
+       class MyRedirectBot(ExistingPageBot):
+
+           '''Bot who only works on existing redirects.'''
+
+           use_redirects = True
 
     .. versionadded:: 7.2
     """
 
-    # Handler configuration.
-    # The values are the default values
-    # Extend this in subclasses!
-
     available_options = {
         'always': False,  # By default ask for confirmation when putting a page
     }
 
     update_options = {}  # type: Dict[str, Any]
-    """update_options can be used to update available_options;
+    """`update_options` can be used to update :attr:`available_options`;
     do not use it if the bot class is to be derived but use
-    self.available_options.update(<dict>) initializer in such case.
+    `self.available_options.update(<dict>)` initializer in such case.
 
     .. versionadded:: 6.4
     """
@@ -1264,7 +1294,7 @@ class BaseBot(OptionHandler):
     _current_page = None  # type: Optional[pywikibot.page.BasePage]
 
     def __init__(self, **kwargs: Any) -> None:
-        """Only accept 'generator' and options defined in available_options.
+        """Initializer.
 
         :param kwargs: bot options
         :keyword generator: a :attr:`generator` processed by :meth:`run` method
@@ -1274,14 +1304,38 @@ class BaseBot(OptionHandler):
                 pywikibot.warn('{} has a generator already. Ignoring argument.'
                                .format(self.__class__.__name__))
             else:
-                #: generator processed by :meth:`run` method
-                self.generator = kwargs.pop('generator')
+                #: instance variable to hold the generator processed by
+                #: :meth:`run` method
+                self.generator = kwargs.pop('generator')  # type: Iterable
 
         self.available_options.update(self.update_options)
         super().__init__(**kwargs)
 
-        self.counter = Counter()
-        self._generator_completed = False
+        self.counter = Counter()  # type: Counter
+        """Instance variable which holds counters. The default counters
+        are 'read', 'write' and 'skip'. You can use your own counters like::
+
+            self.counter['delete'] += 1
+
+        .. versionadded:: 7.0
+        .. versionchanged:: 7.3
+           Your additional counters are also printed during :meth:`exit`
+        """
+
+        self.generator_completed = False  # type: bool
+        """Instance attribute which is True if the generator is completed.
+
+        To check for an empty generator you may use::
+
+            if self.generator_completed and not self.counter['read']:
+                print('generator was emtpty')
+
+        .. note:: An empty generator remains False.
+        .. versionadded:: 3.0
+        .. versionchanged:: 7.4
+           renamed to `generator_completed` to become a public attribute.
+        """
+
         #: instance variable to hold the default page type
         self.treat_page_type = pywikibot.page.BasePage  # type: Any
 
@@ -1373,21 +1427,18 @@ class BaseBot(OptionHandler):
         """
         Save a new revision of a page, with user confirmation as required.
 
-        Print differences, ask user for confirmation,
-        and puts the page if needed.
+        Print differences, ask user for confirmation, and puts the page
+        if needed.
 
         Option used:
 
         * 'always'
 
-        Keyword args used:
-
-        * 'asynchronous' - passed to page.save
-        * 'summary' - passed to page.save
-        * 'show_diff' - show changes between oldtext and newtext (enabled)
-        * 'ignore_save_related_errors' - report and ignore (disabled)
-        * 'ignore_server_errors' - report and ignore (disabled)
-
+        :keyword asynchronous: passed to page.save
+        :keyword summary: passed to page.save
+        :keyword show_diff: show changes between oldtext and newtext (enabled)
+        :keyword ignore_save_related_errors: report and ignore (disabled)
+        :keyword ignore_server_errors: report and ignore (disabled)
         :return: whether the page was saved successfully
         """
         if oldtext.rstrip() == newtext.rstrip():
@@ -1398,7 +1449,6 @@ class BaseBot(OptionHandler):
         self.current_page = page
 
         show_diff = kwargs.pop('show_diff', True)
-
         if show_diff:
             pywikibot.showDiff(oldtext, newtext)
 
@@ -1414,6 +1464,8 @@ class BaseBot(OptionHandler):
         """
         Helper function to handle page save-related option error handling.
 
+        .. note:: Do no use it directly. Use :meth:`userPut` instead.
+
         :param page: currently edited page
         :param func: the function to call
         :param args: passed to the function
@@ -1425,6 +1477,8 @@ class BaseBot(OptionHandler):
             page save will be reported and ignored (default: False)
         :kwtype ignore_save_related_errors: bool
         :return: whether the page was saved successfully
+
+        :meta public:
         """
         if not self.user_confirm('Do you want to accept these changes?'):
             return False
@@ -1468,13 +1522,17 @@ class BaseBot(OptionHandler):
         raise QuitKeyboardInterrupt
 
     def exit(self) -> None:
-        """
-        Cleanup and exit processing.
+        """Cleanup and exit processing.
 
-        Invoked when Bot.run() is finished.
-        Prints treat and save counters and informs whether the script
+        Invoked when :meth:`run` is finished. Waits for pending threads,
+        prints counter statistics and informs whether the script
         terminated gracefully or was halted by exception.
-        May be overridden by subclasses.
+
+        .. note:: Do not overwrite it by subclasses; :meth:`teardown`
+           should be used instead.
+
+        .. versionchanged:: 7.3
+           Statistics are printed for all entries in :attr:`counter`
         """
         self.teardown()
         if hasattr(self, '_start_ts'):
@@ -1484,10 +1542,10 @@ class BaseBot(OptionHandler):
         # wait until pending threads finished but don't close the queue
         pywikibot.stopme()
 
-        pywikibot.output('\n{read} pages read'
-                         '\n{write} pages written'
-                         '\n{skip} pages skipped'
-                         .format_map(self.counter))
+        pywikibot.info()
+        for op, count in self.counter.items():
+            pywikibot.info('{} {} operation{}'
+                           .format(count, op, 's' if count > 1 else ''))
 
         if hasattr(self, '_start_ts'):
             write_delta = pywikibot.Timestamp.now() - self._start_ts
@@ -1503,10 +1561,12 @@ class BaseBot(OptionHandler):
             if self.counter['read']:
                 pywikibot.output('Read operation time: {:.1f} seconds'
                                  .format(read_seconds / self.counter['read']))
-            if self.counter['write']:
-                pywikibot.output(
-                    'Write operation time: {:.1f} seconds'
-                    .format(write_seconds / self.counter['write']))
+
+            for op, count in self.counter.items():
+                if not count or op == 'read':
+                    continue
+                pywikibot.info('{} operation time: {:.1f} seconds'
+                               .format(op.capitalize(), write_seconds / count))
 
         # exc_info contains exception from self.run() while terminating
         exc_info = sys.exc_info()
@@ -1515,18 +1575,20 @@ class BaseBot(OptionHandler):
             pywikibot.output('successfully.')
         else:
             pywikibot.output('by exception:\n')
-            pywikibot.exception()
+            pywikibot.exception(exc_info=False)
 
     def init_page(self, item: Any) -> 'pywikibot.page.BasePage':
         """Initialize a generator item before treating.
 
-        Ensure that the result of init_page is always a pywikibot.Page object
-        even when the generator returns something else.
+        Ensure that the result of `init_page` is always a
+        pywikibot.Page object or any other type given by the
+        :attr:`treat_page_type` even when the generator returns
+        something else.
 
-        Also used to set the arrange the current site. This is called before
-        skip_page and treat.
+        Also used to set the arrange the current site. This is called
+        before :meth:`skip_page` and :meth:`treat`.
 
-        :param item: any item from self.generator
+        :param item: any item from :attr:`generator`
         :return: return the page object to be processed further
         """
         return item
@@ -1564,24 +1626,25 @@ class BaseBot(OptionHandler):
         """Process one page (abstract method).
 
         :param page: Object to be processed, usually a
-            :class:`pywikibot.page.BasePage`. For other page types the
+            :class:`page.BasePage`. For other page types the
             :attr:`treat_page_type` must be set.
         """
         raise NotImplementedError('Method {}.treat() not implemented.'
                                   .format(self.__class__.__name__))
 
     def setup(self) -> None:
-        """Some initial setup before run operation starts.
+        """Some initial setup before :meth:`run` operation starts.
 
         This can be used for reading huge parts from life wiki or file
         operation which is more than just initialize the instance.
-        Invoked by run() before running through generator loop.
+        Invoked by :meth:`run` before running through :attr:`generator`
+        loop.
 
         .. versionadded:: 3.0
         """
 
     def teardown(self) -> None:
-        """Some cleanups after run operation. Invoked by exit().
+        """Some cleanups after :meth:`run` operation. Invoked by :meth:`exit`.
 
         .. versionadded:: 3.0
         """
@@ -1599,6 +1662,8 @@ class BaseBot(OptionHandler):
                                       .format(self.__class__.__name__))
         if not isinstance(self.generator, Generator):
             # to provide close() method
+            pywikibot.info('wrapping {} type to a Generator type'
+                           .format(type(self.generator).__name__))
             self.generator = (item for item in self.generator)
         try:
             for item in self.generator:
@@ -1616,10 +1681,10 @@ class BaseBot(OptionHandler):
                     continue
 
                 # Process the page
-                self.treat(page)
                 self.counter['read'] += 1
+                self.treat(page)
 
-            self._generator_completed = True
+            self.generator_completed = True
         except QuitKeyboardInterrupt:
             pywikibot.output('\nUser quit {} bot run...'
                              .format(self.__class__.__name__))
@@ -1908,7 +1973,7 @@ class AutomaticTWSummaryBot(CurrentPageBot):
     A class which automatically defines ``summary`` for ``put_current``.
 
     The class must defined a ``summary_key`` string which contains the
-    i18n key for :py:obj:`pywikibot.i18n.twtranslate`. It can also
+    i18n key for :py:obj:`i18n.twtranslate`. It can also
     override the ``summary_parameters`` property to specify any
     parameters for the translated message.
     """
@@ -1954,7 +2019,12 @@ class ExistingPageBot(CurrentPageBot):
     """A CurrentPageBot class which only treats existing pages."""
 
     def skip_page(self, page: 'pywikibot.page.BasePage') -> bool:
-        """Treat page if it exists and handle NoPageError."""
+        """Treat page if it exists and handle NoPageError.
+
+        .. warning:: If subclassed, call `super().skip_page()` first to
+           ensure that non existent pages are filtered before other
+           calls are made
+        """
         if not page.exists():
             pywikibot.warning('Page {page} does not exist on {page.site}.'
                               .format(page=page))
@@ -1986,12 +2056,13 @@ class CreatingPageBot(CurrentPageBot):
         return super().skip_page(page)
 
 
-class RedirectPageBot(CurrentPageBot):
+class RedirectPageBot(CurrentPageBot):  # pragma: no cover
 
     """A RedirectPageBot class which only treats redirects.
 
     .. deprecated:: 7.2
-       use BaseBot attribute 'use_redirects = True' instead
+       use BaseBot attribute
+       :attr:`use_redirects  = True<BaseBot.use_redirects>` instead
     """
 
     def __init__(self, *args, **kwargs):
@@ -2011,12 +2082,13 @@ class RedirectPageBot(CurrentPageBot):
         return super().skip_page(page)
 
 
-class NoRedirectPageBot(CurrentPageBot):
+class NoRedirectPageBot(CurrentPageBot):  # pragma: no cover
 
     """A NoRedirectPageBot class which only treats non-redirects.
 
     .. deprecated:: 7.2
-       use BaseBot attribute 'use_redirects = False' instead
+       use BaseBot attribute
+       :attr:`use_redirects  = False<BaseBot.use_redirects>` instead
     """
 
     def __init__(self, *args, **kwargs):
@@ -2167,6 +2239,12 @@ class WikidataBot(Bot, ExistingPageBot):
         :keyword ignore_save_related_errors: if True, errors related to
           page save will be reported and ignored (default: False)
         :return: whether the item was saved successfully
+
+        .. note:: calling this method sets the current_page property
+           to the item which changes the site property
+
+        .. note:: calling this method with the 'source' argument modifies
+           the provided claim object in place
         """
         self.current_page = item
 
@@ -2197,7 +2275,7 @@ class WikidataBot(Bot, ExistingPageBot):
     def user_add_claim_unless_exists(
             self, item: 'pywikibot.page.ItemPage',
             claim: 'pywikibot.page.Claim',
-            exists_arg: str = '',
+            exists_arg: Container = '',
             source: Optional['BaseSite'] = None,
             logger_callback: Callable[[str], Any] = log,
             **kwargs: Any) -> bool:
@@ -2207,14 +2285,29 @@ class WikidataBot(Bot, ExistingPageBot):
         Before adding a new claim, it checks if we can add it, using provided
         filters.
 
-        :see: documentation of :py:obj:`claimit.py<scripts.claimit>`
+        .. seealso:: documentation of :py:obj:`claimit.py<scripts.claimit>`
+
         :param exists_arg: pattern for merging existing claims with new ones
         :param logger_callback: function logging the output of the method
         :return: whether the claim could be added
+
+        .. note:: calling this method may change the current_page property
+           to the item which will also change the site property
+
+        .. note:: calling this method with the 'source' argument modifies
+           the provided claim object in place
         """
+        # This code is somewhat duplicate to user_add_claim but
+        # unfortunately we need the source claim here, too.
+        if source:
+            sourceclaim = self.getSource(source)
+        else:
+            sourceclaim = None
+
         # Existing claims on page of same property
         claims = item.get().get('claims')
         assert claims is not None
+
         for existing in claims.get(claim.getID(), []):
             # If claim with same property already exists...
             if 'p' not in exists_arg:
@@ -2245,17 +2338,20 @@ class WikidataBot(Bot, ExistingPageBot):
                 log("Append 'q' to -exists argument to override this behavior")
                 break
 
-            if ('s' not in exists_arg or not source) and not existing.sources:
+            if ('s' not in exists_arg or not sourceclaim) \
+               and not existing.sources:
                 logger_callback(
                     'Skipping {} because claim without source already exists'
-                    .format(claim.getID(),))
+                    .format(claim.getID()))
                 log("Append 's' to -exists argument to override this behavior")
                 break
 
-            if ('s' not in exists_arg and source
-                and any(source.getID() in ref
-                        and all(snak.target_equals(source.getTarget())
-                                for snak in ref[source.getID()])
+            # FIXME: the user may provide a better source, but we only
+            # assume it's the default one
+            if ('s' not in exists_arg and sourceclaim
+                and any(sourceclaim.getID() in ref
+                        and all(snak.target_equals(sourceclaim.getTarget())
+                                for snak in ref[sourceclaim.getID()])
                         for ref in existing.sources)):
                 logger_callback(
                     'Skipping {} because claim with the same source already '
