@@ -59,7 +59,7 @@ class Option(ABC):
             formatted_options.append(option.format(default=default))
         # remove color highlights before fill function
         text = '{} ({})'.format(text, ', '.join(formatted_options))
-        pattern = '\03{[a-z]+}'
+        pattern = '<<[a-z]+>>'
         highlights = re.findall(pattern, text)
         return fill(re.sub(pattern, '{}', text), width=77).format(*highlights)
 
@@ -105,7 +105,7 @@ class OutputOption(Option):
     .. note:: OutputOption must have an :py:obj:`out` property which
        returns a string for
        :py:meth:`userinterface output()
-       <pywikibot.userinterfaces._interface_base.ABUIC.output>`
+       <userinterfaces._interface_base.ABUIC.output>`
        method.
     """
 
@@ -125,7 +125,9 @@ class OutputOption(Option):
     def out(self) -> str:
         """String to be used when selected before or after the question.
 
-        :Note: This method is used by ui.input_choice instead of output().
+        .. note:: This method is used by :meth:`ui.input_choice
+           <userinterfaces._interface_base.ABUIC.input_choice>`
+           instead of deprecated :meth:`output`.
 
         .. versionadded:: 6.2
         """
@@ -136,7 +138,7 @@ class OutputOption(Option):
         """Output string.
 
         .. deprecated:: 6.5
-           This method was replaced by :py:obj:`out` property and is no
+           This method was replaced by :attr:`out` property and is no
            no longer used by the
            :py:mod:`userinterfaces <pywikibot.userinterfaces>` system.
         """
@@ -193,7 +195,7 @@ class OutputProxyOption(OutputOption, StandardOption):
     @property
     def out(self) -> str:
         """Return the contents."""
-        if not hasattr(self._outputter, 'out'):
+        if not hasattr(self._outputter, 'out'):  # pragma: no cover
             issue_deprecation_warning('{} without "out" property'
                                       .format(self.__class__.__name__),
                                       since='6.2.0')
