@@ -395,6 +395,36 @@ def fetch(uri: str, method: str = 'GET', headers: Optional[dict] = None,
     return response
 
 
+# Extract charset (from content-type header)
+CHARSET_RE = re.compile(
+    r'charset\s*=\s*(?P<q>[\'"]?)(?P<charset>[^\'",;>/]+)(?P=q)',
+    flags=re.I,
+)
+
+
+def get_charset_from_content_type(content_type: str) -> Optional[str]:
+    """Get charset from the content-type header.
+
+    .. versionadded:: 7.3
+    """
+    m = CHARSET_RE.search(content_type)
+    if not m:
+        return None
+    charset = m.group('charset').strip('"\' ').lower()
+    # Convert to python correct encoding names
+    if re.sub(r'[ _\-]', '', charset) == 'xeucjp':
+        charset = 'euc_jp'
+    else:
+        # fix cp encodings (T304830, T307760, T312230)
+        # remove delimiter in front of the code number
+        # replace win/windows with cp
+        # remove language code in font of win/windows
+        charset = re.sub(
+            r'\A(?:cp[ _\-]|(?:[a-z]+[_\-]?)?win(?:dows)?[_\-]?)(\d{3,4})',
+            r'cp\1', charset)
+    return charset
+
+
 def _get_encoding_from_response_headers(response) -> Optional[str]:
     """Return charset given by the response header."""
     content_type = response.headers.get('content-type')
@@ -402,9 +432,9 @@ def _get_encoding_from_response_headers(response) -> Optional[str]:
     if not content_type:
         return None
 
-    m = re.search('charset=(?P<charset>.*?$)', content_type)
-    if m:
-        header_encoding = m.group('charset')
+    charset = get_charset_from_content_type(content_type)
+    if charset:
+        header_encoding = charset
     elif 'json' in content_type:
         # application/json | application/sparql-results+json
         header_encoding = 'utf-8'
@@ -450,25 +480,19 @@ def _decide_encoding(response, charset) -> Optional[str]:
 
     # No charset requested, or in request headers or response headers.
     # Defaults to latin1.
-    if charset is None and header_encoding is None:
-        return _try_decode(response.content, 'latin1')
+    if charset is None:
+        return _try_decode(response.content, header_encoding or 'latin1')
 
-    if charset is None and header_encoding is not None:
-        return _try_decode(response.content, header_encoding)
-
-    if charset is not None and header_encoding is None:
+    if header_encoding is None:
         return _try_decode(response.content, charset)
 
     # Both charset and header_encoding are available.
-    try:
+    header_codecs = charset_codecs = None
+    with suppress(LookupError):
         header_codecs = codecs.lookup(header_encoding)
-    except LookupError:
-        header_codecs = None
 
-    try:
+    with suppress(LookupError):
         charset_codecs = codecs.lookup(charset)
-    except LookupError:
-        charset_codecs = None
 
     if header_codecs and charset_codecs and header_codecs != charset_codecs:
         pywikibot.warning(
