@@ -7,7 +7,7 @@ If you wish to run this as an stand-alone script, use::
 
     scripts/cosmetic_changes.py
 
-For regular use, it is recommended to put this line into your user-config.py::
+For regular use, it is recommended to put this line into your user config::
 
     cosmetic_changes = True
 
@@ -15,7 +15,7 @@ You may enable cosmetic changes for additional languages by adding the
 dictionary cosmetic_changes_enable to your user-config.py. It should contain
 a tuple of languages for each site where you wish to enable in addition to
 your own langlanguage if cosmetic_changes_mylang_only is True (see below).
-Please set your dictionary by adding such lines to your user-config.py::
+Please set your dictionary by adding such lines to your user config::
 
     cosmetic_changes_enable['wikipedia'] = ('de', 'en', 'fr')
 
@@ -26,13 +26,14 @@ There is another config variable: You can set::
 if you're running a bot on multiple sites and want to do cosmetic changes on
 all of them, but be careful if you do.
 
-You may disable cosmetic changes by adding the all unwanted languages to the
-dictionary cosmetic_changes_disable in your user-config.py. It should contain
-a tuple of languages for each site where you wish to disable cosmetic changes.
-You may use it with cosmetic_changes_mylang_only is False, but you can also
-disable your own language. This also overrides the settings in the dictionary
-cosmetic_changes_enable. Please set this dictionary by adding such lines to
-your user-config.py::
+You may disable cosmetic changes by adding the all unwanted languages to
+the `dictionary cosmetic_changes_disable` in your user config file
+(`user_config.py`). It should contain a tuple of languages for each site
+where you wish to disable cosmetic changes. You may use it with
+`cosmetic_changes_mylang_only` is False, but you can also disable your
+own language. This also overrides the settings in the dictionary
+`cosmetic_changes_enable`. Please set this dictionary by adding such
+lines to your user config file::
 
     cosmetic_changes_disable['wikipedia'] = ('de', 'en', 'fr')
 
@@ -55,6 +56,7 @@ or by adding a list to the given one::
 # Distributed under the terms of the MIT license.
 #
 import re
+from contextlib import suppress
 from enum import IntEnum
 from typing import Any, Union
 from urllib.parse import urlparse, urlunparse
@@ -387,7 +389,11 @@ class CosmeticChangesToolkit:
         return text
 
     def translateAndCapitalizeNamespaces(self, text: str) -> str:
-        """Use localized namespace names."""
+        """Use localized namespace names.
+
+        .. versionchanged:: 7.4
+           No longer expect a specific namespace alias for File:
+        """
         # arz uses English stylish codes
         if self.site.sitename == 'wikipedia:arz':
             return text
@@ -403,17 +409,17 @@ class CosmeticChangesToolkit:
             if namespace == 6 and self.site.family.name == 'wikipedia':
                 if self.site.code in ('en', 'fr'):
                     # do not change "Image" on en-wiki and fr-wiki
-                    assert 'Image' in namespaces
-                    namespaces.remove('Image')
+                    with suppress(ValueError):
+                        namespaces.remove('Image')
                 if self.site.code == 'hu':
                     # do not change "Kép" on hu-wiki
-                    assert 'Kép' in namespaces
-                    namespaces.remove('Kép')
+                    with suppress(ValueError):
+                        namespaces.remove('Kép')
                 elif self.site.code == 'pt':
                     # use "Imagem" by default on pt-wiki (per T57242)
-                    assert 'Imagem' in namespaces
-                    namespaces.insert(
-                        0, namespaces.pop(namespaces.index('Imagem')))
+                    with suppress(ValueError):
+                        namespaces.insert(
+                            0, namespaces.pop(namespaces.index('Imagem')))
             # final namespace variant
             final_ns = namespaces.pop(0)
             if namespace in (2, 3):
@@ -747,11 +753,11 @@ class CosmeticChangesToolkit:
 
         == Section title ==
 
-        :NOTE: This space is recommended in the syntax help on the
-            English and German Wikipedias. It is not wanted on Lojban and
-            English Wiktionaries (T168399, T169064) and it might be that
-            it is not wanted on other wikis. If there are any complaints,
-            please file a bug report.
+        .. note:: This space is recommended in the syntax help on the
+           English and German Wikipedias. It is not wanted on Lojban and
+           English Wiktionaries (:phab:`T168399`, :phab:`T169064`) and
+           it might be that it is not wanted on other wikis. If there
+           are any complaints, please file a bug report.
         """
         if self.site.sitename in ['wiktionary:jbo', 'wiktionary:en']:
             return text
@@ -765,10 +771,10 @@ class CosmeticChangesToolkit:
         """
         Add a space between the * or # and the text.
 
-        :NOTE: This space is recommended in the syntax help on the
-            English, German and French Wikipedias. It might be that it
-            is not wanted on other wikis. If there are any complaints,
-            please file a bug report.
+        .. note:: This space is recommended in the syntax help on the
+           English, German and French Wikipedias. It might be that it
+           is not wanted on other wikis. If there are any complaints,
+           please file a bug report.
         """
         if not self.template:
             exceptions = ['comment', 'math', 'nowiki', 'pre',
@@ -810,8 +816,9 @@ class CosmeticChangesToolkit:
         def replace_link(match: Match[str]) -> str:
             """Create a string to replace a single link."""
             replacement = '[['
-            if re.match(r'(?:' + '|'.join(list(self.site.namespaces[6])
-                        + list(self.site.namespaces[14])) + '):',
+            if re.match(r'(?:{}):'
+                        .format('|'.join((*self.site.namespaces[6],
+                                          *self.site.namespaces[14]))),
                         match.group('link')):
                 replacement += ':'
             replacement += match.group('link')
