@@ -1,6 +1,6 @@
 """Module to daemonize the current process on Unix."""
 #
-# (C) Pywikibot team, 2007-2021
+# (C) Pywikibot team, 2007-2022
 #
 # Distributed under the terms of the MIT license.
 #
@@ -8,15 +8,14 @@ import codecs
 import os
 import stat
 import sys
-
-from pywikibot.tools import deprecated_args
+from typing import Optional
 
 
 is_daemon = False
 
 
-@deprecated_args(write_pid=True)
-def daemonize(close_fd=True, chdir=True, redirect_std=None):
+def daemonize(close_fd: bool = True, chdir: bool = True,
+              redirect_std: Optional[str] = None) -> None:
     """
     Daemonize the current process.
 
@@ -24,11 +23,8 @@ def daemonize(close_fd=True, chdir=True, redirect_std=None):
     The process will fork to the background and return control to terminal.
 
     :param close_fd: Close the standard streams and replace them by /dev/null
-    :type close_fd: bool
     :param chdir: Change the current working directory to /
-    :type chdir: bool
     :param redirect_std: Filename to redirect stdout and stdin to
-    :type redirect_std: str
     """
     # Fork away
     if not os.fork():
@@ -60,10 +56,11 @@ def daemonize(close_fd=True, chdir=True, redirect_std=None):
             if chdir:
                 os.chdir('/')
             return
+
         # Write out the pid
         path = os.path.basename(sys.argv[0]) + '.pid'
         with codecs.open(path, 'w', 'utf-8') as f:
             f.write(str(pid))
     # Exit to return control to the terminal
     # os._exit to prevent the cleanup to run
-    os._exit(0)
+    os._exit(os.EX_OK)
