@@ -4,7 +4,7 @@
 #
 # Distributed under the terms of the MIT license.
 #
-import json
+from contextlib import suppress
 from typing import Optional
 from urllib.parse import quote
 
@@ -16,6 +16,11 @@ from pywikibot.comms import http
 from pywikibot.exceptions import Error, TimeoutError
 
 
+try:
+    from requests import JSONDecodeError
+except ImportError:  # requests < 2.27.0
+    from json import JSONDecodeError
+
 DEFAULT_HEADERS = {'cache-control': 'no-cache',
                    'Accept': 'application/sparql-results+json'}
 
@@ -49,7 +54,7 @@ class SparqlQuery:
         """
         # default to Wikidata
         if not repo and not endpoint:
-            repo = Site('wikidata', 'wikidata')
+            repo = Site('wikidata')
 
         if repo:
             try:
@@ -148,13 +153,9 @@ class SparqlQuery:
                 self.wait()
                 continue
 
-            if not self.last_response.text:
-                break
-
-            try:
-                return json.loads(self.last_response.text)
-            except ValueError:
-                break
+            with suppress(JSONDecodeError):
+                return self.last_response.json()
+            break
 
         return None
 
