@@ -28,9 +28,10 @@ class TextEditor:
 
     """Text editor."""
 
-    def _command(self, file_name: str, text: str,
+    @staticmethod
+    def _command(file_name: str, text: str,
                  jump_index: Optional[int] = None) -> List[str]:
-        """Return editor selected in user-config.py."""
+        """Return editor selected in user config file (user-config.py)."""
         if jump_index:
             # Some editors make it possible to mark occurrences of substrings,
             # or to jump to the line of the first occurrence.
@@ -45,9 +46,7 @@ class TextEditor:
         assert config.editor is not None
         if config.editor.startswith('kate'):
             command = ['-l', str(line + 1), '-c', str(column + 1)]
-        elif config.editor.startswith('gedit'):
-            command = ['+{}'.format(line + 1)]  # columns seem unsupported
-        elif config.editor.startswith('emacs'):
+        elif config.editor.startswith(('gedit', 'emacs')):
             command = ['+{}'.format(line + 1)]  # columns seem unsupported
         elif config.editor.startswith('jedit'):
             command = ['+line:{}'.format(line + 1)]  # columns seem unsupported
