@@ -68,7 +68,7 @@ the framework::
 
 Error: Base class, all exceptions should the subclass of this class.
 
-  - NoUsernameError: Username is not in user-config.py, or it is invalid.
+  - NoUsernameError: Username is not in user config file, or it is invalid.
   - AutoblockUserError: requested action on a virtual autoblock user not valid
   - TranslationError: no language translation found
   - UserRightsError: insufficient rights for requested action
@@ -193,9 +193,9 @@ class Error(Exception):
 
     """Pywikibot error."""
 
-    def __init__(self, arg: str) -> None:
+    def __init__(self, arg: Union[Exception, str]) -> None:
         """Initializer."""
-        self.unicode = arg
+        self.unicode = str(arg)
 
     def __str__(self) -> str:
         """Return a string representation."""
@@ -343,7 +343,7 @@ class OtherPageSaveError(PageSaveRelatedError):
 
 class NoUsernameError(Error):
 
-    """Username is not in user-config.py."""
+    """Username is not in user config file (user-config.py)."""
 
 
 class NoPageError(PageRelatedError):
@@ -447,7 +447,7 @@ class InterwikiRedirectPageError(PageRelatedError):
     """
     Page is a redirect to another site.
 
-    This is considered invalid in Pywikibot. See bug T75184.
+    This is considered invalid in Pywikibot. See bug :phab:`T75184`.
 
     """
 
