@@ -1,6 +1,6 @@
 """Family module for Wikimedia Commons."""
 #
-# (C) Pywikibot team, 2005-2020
+# (C) Pywikibot team, 2005-2022
 #
 # Distributed under the terms of the MIT license.
 #
@@ -38,3 +38,10 @@ class Family(family.WikimediaFamily):
     doc_subpages = {
         '_default': (('/doc', ), ['commons']),
     }
+
+    def interface(self, code) -> str:
+        """Return 'DataSite' to enable structured data.
+
+        .. versionadded 6.5
+        """
+        return 'DataSite'
