@@ -1,6 +1,6 @@
 """Family module for Translate Wiki."""
 #
-# (C) Pywikibot team, 2007-2020
+# (C) Pywikibot team, 2007-2022
 #
 # Distributed under the terms of the MIT license.
 #
@@ -15,6 +15,6 @@ class Family(family.SingleSiteFamily):
     name = 'i18n'
     domain = 'translatewiki.net'
 
-    def protocol(self, code):
+    def protocol(self, code) -> str:
         """Return https as the protocol for this family."""
         return 'https'
