@@ -1,6 +1,6 @@
-"""Family module for WOW Wiki."""
+"""Family module for WOW wiki."""
 #
-# (C) Pywikibot team, 2009-2021
+# (C) Pywikibot team, 2009-2022
 #
 # Distributed under the terms of the MIT license.
 #
