@@ -21,7 +21,7 @@ import pywikibot
 from pywikibot import config
 from pywikibot.backports import Dict, List, Set, Tuple  # skipcq: PY-W2000
 from pywikibot.exceptions import FamilyMaintenanceWarning, UnknownFamilyError
-from pywikibot.tools import classproperty, deprecated
+from pywikibot.tools import classproperty, deprecated, remove_last_args
 
 
 logger = logging.getLogger('pywiki.wiki.family')
@@ -29,7 +29,7 @@ logger = logging.getLogger('pywiki.wiki.family')
 # Legal characters for Family.name and Family.langs keys
 NAME_CHARACTERS = string.ascii_letters + string.digits
 # nds_nl code alias requires "_"n
-# dash must be the last char to be reused as regex in update_linktrails
+# dash must be the last char to be reused as regex
 CODE_CHARACTERS = string.ascii_lowercase + string.digits + '_-'
 
 
@@ -84,7 +84,7 @@ class Family:
         'ab', 'ar', 'an', 'arc', 'roa-rup', 'frp', 'as', 'ast', 'atj', 'awa',
         'gn', 'av', 'ay', 'az', 'ban', 'bm', 'bn', 'bjn', 'zh-min-nan', 'nan',
         'map-bms', 'ba', 'be', 'be-tarask', 'mnw', 'bh', 'bcl', 'bi', 'bg',
-        'bar', 'bo', 'bs', 'br', 'bxr', 'ca', 'cv', 'ceb', 'cs', 'ch',
+        'bar', 'blk', 'bo', 'bs', 'br', 'bxr', 'ca', 'cv', 'ceb', 'cs', 'ch',
         'cbk-zam', 'ny', 'sn', 'tum', 'cho', 'co', 'cy', 'dag', 'da', 'dk',
         'ary', 'pdc', 'de', 'dv', 'nv', 'dsb', 'dty', 'dz', 'mh', 'et', 'el',
         'eml', 'en', 'myv', 'es', 'eo', 'ext', 'eu', 'ee', 'fa', 'hif', 'fo',
@@ -101,15 +101,15 @@ class Family:
         'my', 'nah', 'na', 'fj', 'nl', 'nds-nl', 'cr', 'ne', 'new', 'nia',
         'ja', 'nqo', 'nap', 'ce', 'frr', 'pih', 'no', 'nb', 'nn', 'nrm', 'nov',
         'ii', 'oc', 'mhr', 'or', 'om', 'ng', 'hz', 'uz', 'pa', 'pi', 'pfl',
-        'pag', 'ami', 'pnb', 'pap', 'ps', 'jam', 'koi', 'km', 'pcd', 'pms',
-        'pwn', 'tpi', 'nds', 'pl', 'pnt', 'pt', 'aa', 'kaa', 'crh', 'ty',
-        'ksh', 'ro', 'rmy', 'rm', 'qu', 'rue', 'ru', 'sah', 'szy', 'se', 'sm',
-        'sa', 'sg', 'sat', 'skr', 'sc', 'sco', 'trv', 'stq', 'st', 'nso', 'tn',
-        'sq', 'scn', 'si', 'simple', 'sd', 'ss', 'sk', 'sl', 'cu', 'szl', 'so',
-        'ckb', 'srn', 'sr', 'sh', 'su', 'fi', 'sv', 'shi', 'tl', 'shn', 'ta',
-        'kab', 'roa-tara', 'tt', 'tay', 'te', 'tet', 'th', 'ti', 'tg', 'to',
-        'chr', 'chy', 've', 'tcy', 'tr', 'azb', 'tk', 'tw', 'tyv', 'din',
-        'udm', 'bug', 'uk', 'ur', 'ug', 'za', 'vec', 'vep', 'vi', 'vo',
+        'pag', 'ami', 'pnb', 'pap', 'ps', 'jam', 'koi', 'km', 'pcd', 'pcm',
+        'pms', 'pwn', 'tpi', 'nds', 'pl', 'pnt', 'pt', 'aa', 'kaa', 'crh',
+        'ty', 'ksh', 'ro', 'rmy', 'rm', 'qu', 'rue', 'ru', 'sah', 'szy', 'se',
+        'sm', 'sa', 'sg', 'sat', 'skr', 'sc', 'sco', 'trv', 'stq', 'st', 'nso',
+        'tn', 'sq', 'scn', 'si', 'simple', 'sd', 'ss', 'sk', 'sl', 'cu', 'szl',
+        'so', 'ckb', 'srn', 'sr', 'sh', 'su', 'fi', 'sv', 'shi', 'tl', 'shn',
+        'ta', 'kab', 'roa-tara', 'tt', 'tay', 'te', 'tet', 'th', 'ti', 'tg',
+        'to', 'chr', 'chy', 've', 'tcy', 'tr', 'azb', 'tk', 'tw', 'kcg', 'tyv',
+        'din', 'udm', 'bug', 'uk', 'ur', 'ug', 'za', 'vec', 'vep', 'vi', 'vo',
         'fiu-vro', 'wa', 'zh-classical', 'vls', 'war', 'wo', 'wuu', 'ts', 'yi',
         'yo', 'zh-yue', 'diq', 'zea', 'bat-smg', 'zh', 'zh-tw', 'zh-cn',
     ]
@@ -117,21 +117,21 @@ class Family:
     # The revised sorting order by first word from meta
     # MediaWiki:Interwiki_config-sorting_order-native-languagename-firstword
     alphabetic_revised = [
-        'ace', 'ady', 'kbd', 'af', 'ak', 'als', 'alt', 'am', 'smn', 'ang',
-        'ab', 'ar', 'an', 'arc', 'roa-rup', 'frp', 'as', 'ast', 'atj', 'awa',
-        'gn', 'av', 'ay', 'az', 'bjn', 'id', 'ms', 'ban', 'bm', 'bn',
+        'ace', 'ady', 'kbd', 'af', 'ak', 'als', 'alt', 'kcg', 'am', 'smn',
+        'ang', 'ab', 'ar', 'an', 'arc', 'roa-rup', 'frp', 'as', 'ast', 'atj',
+        'awa', 'gn', 'av', 'ay', 'az', 'bjn', 'id', 'ms', 'ban', 'bm', 'bn',
         'zh-min-nan', 'nan', 'map-bms', 'jv', 'su', 'ba', 'min', 'be',
-        'be-tarask', 'mnw', 'mad', 'bh', 'bcl', 'bi', 'bar', 'bo', 'bs', 'br',
-        'bug', 'bg', 'bxr', 'ca', 'ceb', 'cv', 'cs', 'ch', 'cbk-zam', 'ny',
-        'sn', 'tum', 'cho', 'co', 'cy', 'dag', 'da', 'dk', 'ary', 'pdc', 'de',
-        'dv', 'nv', 'dsb', 'na', 'dty', 'dz', 'mh', 'et', 'el', 'eml', 'en',
-        'myv', 'es', 'eo', 'ext', 'eu', 'ee', 'fa', 'hif', 'fo', 'fr', 'fy',
-        'ff', 'fur', 'ga', 'gv', 'sm', 'gag', 'gd', 'gl', 'gan', 'ki', 'glk',
-        'guw', 'gu', 'got', 'hak', 'xal', 'ko', 'ha', 'haw', 'hy', 'hi', 'ho',
-        'hsb', 'hr', 'hyw', 'io', 'ig', 'ilo', 'inh', 'bpy', 'ia', 'ie', 'iu',
-        'ik', 'os', 'xh', 'zu', 'is', 'it', 'he', 'kl', 'kn', 'kr', 'pam',
-        'ka', 'ks', 'csb', 'kk', 'kw', 'rw', 'ky', 'rn', 'mrj', 'sw', 'kv',
-        'kg', 'gom', 'avk', 'gor', 'ht', 'gcr', 'ku', 'shn', 'kj', 'lld',
+        'be-tarask', 'mnw', 'mad', 'bh', 'bcl', 'bi', 'bar', 'blk', 'bo', 'bs',
+        'br', 'bug', 'bg', 'bxr', 'ca', 'ceb', 'cv', 'cs', 'ch', 'cbk-zam',
+        'ny', 'sn', 'tum', 'cho', 'co', 'cy', 'dag', 'da', 'dk', 'ary', 'pdc',
+        'de', 'dv', 'nv', 'dsb', 'na', 'dty', 'dz', 'mh', 'et', 'el', 'eml',
+        'en', 'myv', 'es', 'eo', 'ext', 'eu', 'ee', 'fa', 'hif', 'fo', 'fr',
+        'fy', 'ff', 'fur', 'ga', 'gv', 'sm', 'gag', 'gd', 'gl', 'gan', 'ki',
+        'glk', 'guw', 'gu', 'got', 'hak', 'xal', 'ko', 'ha', 'haw', 'hy', 'hi',
+        'ho', 'hsb', 'hr', 'hyw', 'io', 'ig', 'ilo', 'inh', 'bpy', 'ia', 'ie',
+        'iu', 'ik', 'os', 'xh', 'zu', 'is', 'it', 'he', 'kl', 'kn', 'kr',
+        'pam', 'ka', 'ks', 'csb', 'kk', 'kw', 'rw', 'ky', 'rn', 'mrj', 'sw',
+        'kv', 'kg', 'gom', 'avk', 'gor', 'ht', 'gcr', 'ku', 'shn', 'kj', 'lld',
         'lad', 'lbe', 'lez', 'lfn', 'lo', 'la', 'ltg', 'lv', 'to', 'lb', 'lt',
         'lij', 'li', 'ln', 'nia', 'olo', 'jbo', 'lg', 'lmo', 'lrc', 'hu',
         'mai', 'mk', 'mg', 'ml', 'krc', 'mt', 'mi', 'mr', 'xmf', 'arz', 'mzn',
@@ -139,16 +139,17 @@ class Family:
         'fj', 'nl', 'nds-nl', 'cr', 'ne', 'new', 'ja', 'nqo', 'nap', 'ce',
         'frr', 'pih', 'no', 'nb', 'nn', 'nrm', 'nov', 'ii', 'oc', 'mhr', 'or',
         'om', 'ng', 'hz', 'uz', 'pa', 'pi', 'pfl', 'pag', 'ami', 'pnb', 'pap',
-        'ps', 'jam', 'km', 'pcd', 'pms', 'pwn', 'nds', 'pl', 'pnt', 'pt', 'aa',
-        'kaa', 'crh', 'ty', 'ksh', 'ro', 'rmy', 'rm', 'qu', 'ru', 'rue', 'sah',
-        'szy', 'se', 'sa', 'sg', 'sat', 'skr', 'sc', 'sco', 'trv', 'stq', 'st',
-        'nso', 'tn', 'sq', 'scn', 'si', 'simple', 'sd', 'ss', 'sk', 'sl', 'cu',
-        'szl', 'so', 'ckb', 'srn', 'sr', 'sh', 'fi', 'sv', 'shi', 'tl', 'ta',
-        'kab', 'kbp', 'roa-tara', 'tt', 'tay', 'te', 'tet', 'th', 'vi', 'ti',
-        'tg', 'tpi', 'chr', 'chy', 've', 'tcy', 'tr', 'azb', 'tk', 'tw', 'tyv',
-        'din', 'udm', 'uk', 'ur', 'ug', 'za', 'vec', 'vep', 'vo', 'fiu-vro',
-        'wa', 'zh-classical', 'vls', 'war', 'wo', 'wuu', 'ts', 'yi', 'yo',
-        'zh-yue', 'diq', 'zea', 'bat-smg', 'zh', 'zh-tw', 'zh-cn',
+        'ps', 'jam', 'km', 'pcd', 'pcm', 'pms', 'pwn', 'nds', 'pl', 'pnt',
+        'pt', 'aa', 'kaa', 'crh', 'ty', 'ksh', 'ro', 'rmy', 'rm', 'qu', 'ru',
+        'rue', 'sah', 'szy', 'se', 'sa', 'sg', 'sat', 'skr', 'sc', 'sco',
+        'trv', 'stq', 'st', 'nso', 'tn', 'sq', 'scn', 'si', 'simple', 'sd',
+        'ss', 'sk', 'sl', 'cu', 'szl', 'so', 'ckb', 'srn', 'sr', 'sh', 'fi',
+        'sv', 'shi', 'tl', 'ta', 'kab', 'kbp', 'roa-tara', 'tt', 'tay', 'te',
+        'tet', 'th', 'vi', 'ti', 'tg', 'tpi', 'chr', 'chy', 've', 'tcy', 'tr',
+        'azb', 'tk', 'tw', 'tyv', 'din', 'udm', 'uk', 'ur', 'ug', 'za', 'vec',
+        'vep', 'vo', 'fiu-vro', 'wa', 'zh-classical', 'vls', 'war', 'wo',
+        'wuu', 'ts', 'yi', 'yo', 'zh-yue', 'diq', 'zea', 'bat-smg', 'zh',
+        'zh-tw', 'zh-cn',
     ]
 
     # Order for fy: alphabetical by code, but y counts as i
@@ -157,211 +158,6 @@ class Family:
     fyinterwiki.sort(key=lambda x:
                      x.replace('y', 'i') + x.count('y') * '!')
 
-    # Letters that can follow a wikilink and are regarded as part of
-    # this link. This depends on the linktrail setting in LanguageXx.php
-    #
-    # Do not use this dict directly but Site.linktrail or Family.linktrail
-    # methods instead
-    linktrails = {
-        '_default': '[a-z]*',
-        'ab': '[a-zабвгӷҕдежзӡикқҟлмнопԥҧрстҭуфхҳцҵчҷҽҿшыҩџьә]*',
-        'ady': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӀ]*',
-        'als': '[äöüßa-z]*',
-        'alt': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяјҥӧӱ]*',
-        'ami': '',
-        'an': '[a-záéíóúñ]*',
-        'ar': '[a-zء-يؐ-ًؚ-ٰٟۖ-ۜ۟-۪ۤۧۨ-ۭ]*',
-        'ary': '[a-zء-يؐ-ًؚ-ٰٟۖ-ۜ۟-۪ۤۧۨ-ۭ]*',
-        'arz': '[a-zء-يؐ-ًؚ-ٰٟۖ-ۜ۟-۪ۤۧۨ-ۭ]*',
-        'ast': '[a-záéíóúñ]*',
-        'atj': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'av': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӀ]*',
-        'avk': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'awa': '[a-zऀ-ॣ०-꣠-ꣿ]*',
-        'ay': '[a-záéíóúñ]*',
-        'az': '[a-zçəğıöşü]*',
-        'azb': '[ابپتثجچحخدذرزژسشصضطظعغفقکگلمنوهیآأئؤة‌]*',
-        'ba': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяәөүғҡңҙҫһ“»]*',
-        'bar': '[äöüßa-z]*',
-        'bat-smg': '[a-ząčęėįšųūž]*',
-        'be': '[абвгґджзеёжзійклмнопрстуўфхцчшыьэюяćčłńśšŭźža-z]*',
-        'be-tarask': '[абвгґджзеёжзійклмнопрстуўфхцчшыьэюяćčłńśšŭźža-z]*',
-        'bg': '[a-zабвгдежзийклмнопрстуфхцчшщъыьэюя]*',
-        'bm': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'bn': '[ঀ-৿]*',
-        'bpy': '[ঀ-৿]*',
-        'br': "(?:[a-zA-ZàâçéèêîôûäëïöüùñÇÉÂÊÎÔÛÄËÏÖÜÀÈÙÑ]|[cC]['’]h|C['’]H)*",
-        'bs': '[a-zćčžšđž]*',
-        'bxr': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'ca': "(?:[a-zàèéíòóúç·ïü]|'(?!'))*",
-        'cbk-zam': '[a-záéíóúñ]*',
-        'ce': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӀ]*',
-        'ckb': '[ئابپتجچحخدرڕزژسشعغفڤقکگلڵمنوۆهھەیێ‌]*',
-        'co': '[a-zàéèíîìóòúù]*',
-        'crh': '[a-zâçğıñöşüа-яёʺʹ“»]*',
-        'cs': '[a-záčďéěíňóřšťúůýž]*',
-        'csb': '[a-zęóąśłżźćńĘÓĄŚŁŻŹĆŃ]*',
-        'cu': '[a-zабвгдеєжѕзїіıићклмнопсстѹфхѡѿцчш'
-              'щъыьѣюѥѧѩѫѭѯѱѳѷѵґѓђёјйљњќуўџэ҄я“»]*',
-        'cv': '[a-zа-яĕçăӳ"»]*',
-        'cy': '[àáâèéêìíîïòóôûŵŷa-z]*',
-        'da': '[a-zæøå]*',
-        'dag': '[ɛɣŋɔʒƐƔŊƆƷa-z]*',
-        'de': '[äöüßa-z]*',
-        'din': '[äëɛɛ̈éɣïŋöɔɔ̈óa-z]*',
-        'dsb': '[äöüßa-z]*',
-        'el': '[a-zαβγδεζηθικλμνξοπρστυφχψωςΑΒΓΔΕΖΗΘ'
-              'ΙΚΛΜΝΞΟΠΡΣΤΥΦΧΨΩάέήίόύώϊϋΐΰΆΈΉΊΌΎΏΪΫ]*',
-        'eml': '[a-zàéèíîìóòúù]*',
-        'es': '[a-záéíóúñ]*',
-        'et': '[äöõšüža-z]*',
-        'ext': '[a-záéíóúñ]*',
-        'fa': '[ابپتثجچحخدذرزژسشصضطظعغفقکگلمنوهیآأئؤة‌]*',
-        'ff': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'fi': '[a-zäö]*',
-        'fiu-vro': '[äöõšüža-z]*',
-        'fo': '[áðíóúýæøa-z]*',
-        'fr': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'frp': '[a-zàâçéèêîœôû·’æäåāăëēïīòöōùü‘]*',
-        'frr': '[a-zäöüßåāđē]*',
-        'fur': '[a-zàéèíîìóòúù]*',
-        'fy': '[a-zàáèéìíòóùúâêîôûäëïöü]*',
-        'gag': '[a-zÇĞçğİıÖöŞşÜüÂâÎîÛû]*',
-        'gan': '',
-        'gcr': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'gl': '[áâãàéêẽçíòóôõq̃úüűũa-z]*',
-        'glk': '[ابپتثجچحخدذرزژسشصضطظعغفقکگلمنوهیآأئؤة‌]*',
-        'gn': '[a-záéíóúñ]*',
-        'gu': '[઀-૿]*',
-        'guw': '[a-zàáǎèéěìíǐòóǒùúɛ̌ɔɖẹọ]*',
-        'he': '[a-zא-ת]*',
-        'hi': '[a-zऀ-ॣ०-꣠-ꣿ]*',
-        'hr': '[čšžćđßa-z]*',
-        'hsb': '[äöüßa-z]*',
-        'ht': '[a-zàèòÀÈÒ]*',
-        'hu': '[a-záéíóúöüőűÁÉÍÓÚÖÜŐŰ]*',
-        'hy': '[a-zաբգդեզէըթժիլխծկհձղճմյնշոչպջռսվտրցւփքօֆև«»]*',
-        'hyw': '[a-zաբգդեզէըթժիլխծկհձղճմյնշոչպջռսվտրցւփքօֆև«»]*',
-        'ii': '',
-        'inh': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӀ]*',
-        'is': '[áðéíóúýþæöa-z-–]*',
-        'it': '[a-zàéèíîìóòúù]*',
-        'ka': '[a-zაბგდევზთიკლმნოპჟრსტუფქღყშჩცძწჭხჯჰ“»]*',
-        'kaa': "(?:[a-zıʼ’“»]|'(?!'))*",
-        'kab': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'kbd': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӀ]*',
-        'kbp': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'kk': '[a-zäçéğıïñöşüýʺʹа-яёәғіқңөұүһٴ'
-              'ابپتجحدرزسشعفقكلمنڭەوۇۋۆىيچھ“»]*',
-        'kl': '[a-zæøå]*',
-        'koi': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'krc': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'ksh': '[äöüėëĳßəğåůæœça-z]*',
-        'ku': '[a-zçêîşûẍḧÇÊÎŞÛẌḦ]*',
-        'kv': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'lad': '[a-záéíóúñ]*',
-        'lb': '[äöüßa-z]*',
-        'lbe': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӀ1“»]*',
-        'lez': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӀ]*',
-        'li': '[a-zäöüïëéèà]*',
-        'lij': '[a-zàéèíîìóòúù]*',
-        'lld': '[a-zàéèíîìóòúù]*',
-        'lmo': '[a-zàéèíîìóòúù]*',
-        'ln': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'lrc': '[ابپتثجچحخدذرزژسشصضطظعغفقکگلمنوهیآأئؤة‌]*',
-        'lt': '[a-ząčęėįšųūž]*',
-        'ltg': '[a-zA-ZĀāČčĒēĢģĪīĶķĻļŅņŠšŪūŽž]*',
-        'lv': '[a-zA-ZĀāČčĒēĢģĪīĶķĻļŅņŠšŪūŽž]*',
-        'mai': '[a-zऀ-ॣ०-꣠-ꣿ]*',
-        'mdf': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'mg': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'mhr': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'mk': '[a-zабвгдѓежзѕијклљмнњопрстќуфхцчџш]*',
-        'ml': '[a-zം-ൿ]*',
-        'mn': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя“»]*',
-        'mr': '[ऀ-ॣॱ-ॿ﻿‍]*',
-        'mrj': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'mwl': '[áâãàéêẽçíòóôõq̃úüűũa-z]*',
-        'myv': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'mzn': '[ابپتثجچحخدذرزژسشصضطظعغفقکگلمنوهیآأئؤة‌]*',
-        'nah': '[a-záéíóúñ]*',
-        'nap': '[a-zàéèíîìóòúù]*',
-        'nds': '[äöüßa-z]*',
-        'nds-nl': '[a-zäöüïëéèà]*',
-        'nl': '[a-zäöüïëéèà]*',
-        'nn': '[æøåa-z]*',
-        'no': '[æøåa-z]*',
-        'nrm': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'oc': '[a-zàâçéèêîôû]*',
-        'olo': '[a-zčČšŠžŽäÄöÖ]*',
-        'or': '[a-z଀-୿]*',
-        'os': '[a-zаæбвгдеёжзийклмнопрстуфхцчшщъыьэюя“»]*',
-        'pa': '[ਁਂਃਅਆਇਈਉਊਏਐਓਔਕਖਗਘਙਚਛਜਝਞਟਠਡਢਣਤਥਦਧਨਪਫਬਭਮ'
-              'ਯਰਲਲ਼ਵਸ਼ਸਹ਼ਾਿੀੁੂੇੈੋੌ੍ਖ਼ਗ਼ਜ਼ੜਫ਼ੰੱੲੳa-z]*',
-        'pcd': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'pdc': '[äöüßa-z]*',
-        'pfl': '[äöüßa-z]*',
-        'pl': '[a-zęóąśłżźćńĘÓĄŚŁŻŹĆŃ]*',
-        'pms': '[a-zàéèíîìóòúù]*',
-        'pnt': '[a-zαβγδεζηθικλμνξοπρστυφχψωςΑΒΓΔΕΖΗΘ'
-               'ΙΚΛΜΝΞΟΠΡΣΤΥΦΧΨΩάέήίόύώϊϋΐΰΆΈΉΊΌΎΏΪΫ]*',
-        'pt': '[áâãàéêẽçíòóôõq̃úüűũa-z]*',
-        'pwn': '',
-        'qu': '[a-záéíóúñ]*',
-        'rmy': '[a-zăâîşţșțĂÂÎŞŢȘȚ]*',
-        'ro': '[a-zăâîşţșțĂÂÎŞŢȘȚ]*',
-        'roa-rup': '[a-zăâîşţșțĂÂÎŞŢȘȚ]*',
-        'roa-tara': '[a-zàéèíîìóòúù]*',
-        'ru': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'rue': '[a-zабвгґдеєжзиіїйклмнопрстуфхцчшщьєюяёъы“»]*',
-        'sa': '[a-zऀ-ॣ०-꣠-ꣿ]*',
-        'sah': '[a-zабвгҕдеёжзийклмнҥоөпрсһтуүфхцчшщъыьэюя]*',
-        'scn': '[a-zàéèíîìóòúù]*',
-        'se': '[a-zàáâçčʒǯđðéèêëǧǥȟíìîïıǩŋñóòôõßšŧúùûýÿüžþæøåäö]*',
-        'sg': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'sh': '[a-zčćđžš]*',
-        'shi': '[ⴰ-ⵯa-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙḍḥɛṛɣṣṭẓḌḤƐṚƔṢṬẒʷ]*',
-        'sk': '[a-záäčďéíľĺňóôŕšťúýž]*',
-        'skr': '[آابٻپتٹثجچڄحخدڈݙذرڑزژسشصضطظعغفقکگڳلمنݨوہھیےئأءۃڋڰںؤ]*',
-        'sl': '[a-zčćđžš]*',
-        'smn': '[a-zâčđŋšžäá]*',
-        'sr': '[abvgdđežzijklljmnnjoprstćufhcčdž'
-              'šабвгдђежзијклљмнњопрстћуфхцчџш]*',
-        'srn': '[a-zäöüïëéèà]*',
-        'stq': '[äöüßa-z]*',
-        'sv': '[a-zåäöéÅÄÖÉ]*',
-        'szl': '[a-zęóąśłżźćńĘÓĄŚŁŻŹĆŃ]*',
-        'szy': '',
-        'ta': '[஀-௿]*',
-        'tay': '',
-        'te': '[ఁ-౯]*',
-        'tet': '[áâãàéêẽçíòóôõq̃úüűũa-z]*',
-        'tg': '[a-zабвгдеёжзийклмнопрстуфхчшъэюяғӣқўҳҷцщыь]*',
-        'tk': '[a-zÄäÇçĞğŇňÖöŞşÜüÝýŽž]*',
-        'tr': '[a-zÇĞçğİıÖöŞşÜüÂâÎîÛû]*',
-        'trv': '',
-        'tt': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюяӘәӨөҮүҖҗҢңҺһ]*',
-        'ty': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'tyv': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'udm': '[a-zа-яёӝӟӥӧӵ]*',
-        'uk': '[a-zабвгґдеєжзиіїйклмнопрстуфхцчшщьєюяёъы“»]*',
-        'ur': '[ابپتٹثجچحخدڈذر​ڑ​زژسشصضطظعغفقکگل​م​نںوؤہھیئےآأءۃ]*',
-        'uz': '[a-zʻʼ“»]*',
-        'vec': '[a-zàéèíîìóòúù]*',
-        'vep': '[äöõšüža-z]*',
-        'vi': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'vls': '[a-zäöüïëéèà]*',
-        'wa': '[a-zåâêîôûçéè]*',
-        'wo': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
-        'wuu': '',
-        'xal': '[a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя]*',
-        'xmf': '[a-zაბგდევზთიკლმნოპჟრსტუფქღყშჩცძწჭხჯჰ“»]*',
-        'yi': '[a-zא-ת]*',
-        'za': '',
-        'zea': '[a-zäöüïëéèà]*',
-        'zh': '',
-    }
-
     # A list of category redirect template names in different languages
     category_redirect_templates = {
         '_default': []
@@ -514,7 +310,7 @@ class Family:
     }
 
     # LDAP domain if your wiki uses LDAP authentication,
-    # https://www.mediawiki.org/wiki/Extension:LDAP_Authentication
+    # https://www.mediawiki.org/wiki/Extension:LDAPAuthentication2
     ldapDomain = ()
 
     # Allows crossnamespace interwiki linking.
@@ -573,10 +369,6 @@ class Family:
         if fam is None:
             fam = config.family
 
-        assert all(x in NAME_CHARACTERS for x in fam), \
-            'Name of family "{}" must be ASCII letters and digits ' \
-            '[a-zA-Z0-9]'.format(fam)
-
         if fam in Family._families:
             return Family._families[fam]
 
@@ -621,20 +413,17 @@ class Family:
         Family._families[fam] = cls
         return cls
 
-    def linktrail(self, code, fallback: str = '_default'):
+    @deprecated('APISite.linktrail()', since='7.3.0')
+    @remove_last_args(['fallback'])
+    def linktrail(self, code: str) -> str:
         """Return regex for trailing chars displayed as part of a link.
 
         Returns a string, not a compiled regular expression object.
+
+        .. deprecated:: 7.3
         """
-        if code in self.linktrails:
-            return self.linktrails[code]
-
-        if fallback:
-            return self.linktrails[fallback]
-
-        raise KeyError(
-            'ERROR: linktrail in language {language_code} unknown'
-            .format(language_code=code))
+        site = pywikibot.Site(code, 'wikipedia')
+        return site.linktrail()
 
     def category_redirects(self, code, fallback: str = '_default'):
         """Return list of category redirect templates."""
