@@ -18,6 +18,7 @@ from pywikibot.exceptions import (
     UnknownExtensionError,
 )
 from pywikibot.page import BasePage, PageSourceType, User
+from pywikibot.tools import cached
 
 
 logger = logging.getLogger('pywiki.wiki.flow')
@@ -55,14 +56,13 @@ class FlowPage(BasePage, abc.ABC):
         raise NotImplementedError
 
     @property
+    @cached
     def uuid(self) -> str:
         """Return the UUID of the page.
 
         :return: UUID of the page
         """
-        if not hasattr(self, '_uuid'):
-            self._uuid = self._load()['workflowId']
-        return self._uuid
+        return self._load()['workflowId']
 
     def get(self, force: bool = False, get_redirect: bool = False
             ) -> Dict[str, Any]:
@@ -89,9 +89,15 @@ class Board(FlowPage):
             self._data = self.site.load_board(self)
         return self._data
 
-    def _parse_url(self, links: Mapping[str, Any]) -> Dict[str, Any]:
+    @staticmethod
+    def _parse_url(links: Mapping[str, Any]) -> Dict[str, Any]:
         """Parse a URL retrieved from the API."""
-        rule = links['fwd']
+        if 'fwd' in links:
+            rule = links['fwd']
+        elif 'rev' in links:
+            rule = links['rev']
+        else:
+            raise ValueError('Illegal board data (missing required data).')
         parsed_url = urlparse(rule['url'])
         params = parse_qs(parsed_url.query)
         new_params = {}  # type: Dict[str, Any]
