@@ -15,7 +15,7 @@ __init__.py, and a message bundle called 'pywikibot' containing messages.
 See :py:obj:`twtranslate` for more information on the messages.
 """
 #
-# (C) Pywikibot team, 2004-2021
+# (C) Pywikibot team, 2004-2022
 #
 # Distributed under the terms of the MIT license.
 #
@@ -23,22 +23,30 @@ import json
 import os
 import pkgutil
 import re
-from collections import defaultdict
-from collections.abc import Mapping
+from collections import abc, defaultdict
 from contextlib import suppress
+from pathlib import Path
 from textwrap import fill
 from typing import Optional, Union
 
 import pywikibot
 from pywikibot import __url__, config
-from pywikibot.backports import List, cache
-from pywikibot.plural import plural_rule
-from pywikibot.tools import (
-    ModuleDeprecationWrapper,
-    deprecated_args,
+from pywikibot.backports import (
+    Dict,
+    Generator,
+    Iterable,
+    Iterator,
+    List,
+    Mapping,
+    Match,
+    Sequence,
+    cache,
 )
+from pywikibot.plural import plural_rule
 
 
+STR_OR_SITE_TYPE = Union[str, 'pywikibot.site.BaseSite']
+
 PLURAL_PATTERN = r'{{PLURAL:(?:%\()?([^\)]*?)(?:\)d)?\|(.*?)}}'
 
 # Package name for the translation messages. The messages data must loaded
@@ -349,10 +357,11 @@ _GROUP_NAME_TO_FALLBACKS = {
     'yi': ['he', 'de'],
     'zh-classical': ['zh', 'zh-hans', 'zh-tw', 'zh-cn', 'zh-classical', 'lzh'],
     'zh-min-nan': [
-        'cdo', 'zh', 'zh-hans', 'zh-tw', 'zh-cn', 'zh-classical', 'lzh']}
+        'cdo', 'zh', 'zh-hans', 'zh-tw', 'zh-cn', 'zh-classical', 'lzh']
+}  # type: Dict[str, List[str]]
 
 
-def set_messages_package(package_name: str):
+def set_messages_package(package_name: str) -> None:
     """Set the package name where i18n messages are located."""
     global _messages_package_name
     global _messages_available
@@ -372,7 +381,7 @@ def messages_available() -> bool:
     if _messages_available is not None:
         return _messages_available
     try:
-        mod = __import__(_messages_package_name, fromlist=[str('__path__')])
+        mod = __import__(_messages_package_name, fromlist=['__path__'])
     except ImportError:
         _messages_available = False
         return False
@@ -404,6 +413,24 @@ def _altlang(lang: str) -> List[str]:
 
 
 @cache
+def _get_bundle(lang: str, dirname: str) -> Dict[str, str]:
+    """Return json data of certain bundle if exists.
+
+    For internal use, don't use it directly.
+
+    .. versionadded:: 7.0
+    """
+    filename = '{}/{}.json'.format(dirname, lang)
+    try:
+        data = pkgutil.get_data(_messages_package_name, filename)
+        assert data is not None
+        trans_text = data.decode('utf-8')
+    except OSError:  # file open can cause several exceptions
+        return {}
+
+    return json.loads(trans_text)
+
+
 def _get_translation(lang: str, twtitle: str) -> Optional[str]:
     """
     Return message of certain twtitle if exists.
@@ -411,29 +438,24 @@ def _get_translation(lang: str, twtitle: str) -> Optional[str]:
     For internal use, don't use it directly.
     """
     message_bundle = twtitle.split('-')[0]
-    filename = '{}/{}.json'.format(message_bundle, lang)
-    try:
-        trans_text = pkgutil.get_data(
-            _messages_package_name, filename).decode('utf-8')
-    except OSError:  # file open can cause several exceptions
-        return None
-
-    transdict = json.loads(trans_text)
+    transdict = _get_bundle(lang, message_bundle)
     return transdict.get(twtitle)
 
 
-def _extract_plural(lang: str, message: str, parameters: Mapping) -> str:
+def _extract_plural(lang: str, message: str, parameters: Mapping[str, int]
+                    ) -> str:
     """Check for the plural variants in message and replace them.
 
     :param message: the message to be replaced
     :param parameters: plural parameters passed from other methods
-    :type parameters: Mapping of str to int
     :return: The message with the plural instances replaced
     """
-    def static_plural_value(n):
-        return rule['plural']
+    def static_plural_value(n: int) -> int:
+        plural_rule = rule['plural']
+        assert not callable(plural_rule)
+        return plural_rule
 
-    def replace_plural(match):
+    def replace_plural(match: Match[str]) -> str:
         selector = match.group(1)
         variants = match.group(2)
         num = parameters[selector]
@@ -459,6 +481,8 @@ def _extract_plural(lang: str, message: str, parameters: Mapping) -> str:
         if num in specific_entries:
             return specific_entries[num]
 
+        assert callable(plural_value)
+
         index = plural_value(num)
         needed = rule['nplurals']
         if needed == 1:
@@ -474,15 +498,17 @@ def _extract_plural(lang: str, message: str, parameters: Mapping) -> str:
         'parameters is not Mapping but {}'.format(type(parameters))
 
     rule = plural_rule(lang)
-    plural_value = rule['plural']
-    if not callable(plural_value):
+
+    if callable(rule['plural']):
+        plural_value = rule['plural']
+    else:
         assert rule['nplurals'] == 1
         plural_value = static_plural_value
 
     return re.sub(PLURAL_PATTERN, replace_plural, message)
 
 
-class _PluralMappingAlias(Mapping):
+class _PluralMappingAlias(abc.Mapping):
 
     """
     Aliasing class to allow non mappings in _extract_plural.
@@ -490,15 +516,16 @@ class _PluralMappingAlias(Mapping):
     That function only uses __getitem__ so this is only implemented here.
     """
 
-    def __init__(self, source):
+    def __init__(self, source: Union[int, str, Sequence[int],
+                 Mapping[str, int]]) -> None:
+        self.source = source
         if isinstance(source, str):
             self.source = int(source)
-        else:
-            self.source = source
+
         self.index = -1
         super().__init__()
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> int:
         self.index += 1
         if isinstance(self.source, dict):
             return int(self.source[key])
@@ -508,22 +535,23 @@ class _PluralMappingAlias(Mapping):
                 return int(self.source[self.index])
             raise ValueError('Length of parameter does not match PLURAL '
                              'occurrences.')
+        assert isinstance(self.source, int)
         return self.source
 
-    def __iter__(self):
-        raise NotImplementedError  # pragma: no cover
+    def __iter__(self) -> Iterator[int]:
+        raise NotImplementedError
 
-    def __len__(self):
-        raise NotImplementedError  # pragma: no cover
+    def __len__(self) -> int:
+        raise NotImplementedError
 
 
 DEFAULT_FALLBACK = ('_default', )
 
 
-def translate(code,
-              xdict: Union[dict, str],
-              parameters: Optional[Mapping] = None,
-              fallback=False) -> str:
+def translate(code: STR_OR_SITE_TYPE,
+              xdict: Union[str, Mapping[str, str]],
+              parameters: Optional[Mapping[str, int]] = None,
+              fallback: Union[bool, Iterable[str]] = False) -> Optional[str]:
     """Return the most appropriate localization from a localization dict.
 
     Given a site code and a dictionary, returns the dictionary's value for
@@ -542,7 +570,6 @@ def translate(code,
         extended dictionary the Site object should be used in favour of the
         code string. Otherwise localizations from a wrong family might be
         used.
-    :type code: str or Site object
     :param xdict: dictionary with language codes as keys or extended
         dictionary with family names as keys containing code dictionaries
         or a single string. May contain PLURAL tags as described in
@@ -550,7 +577,6 @@ def translate(code,
     :param parameters: For passing (plural) parameters
     :param fallback: Try an alternate language code. If it's iterable it'll
         also try those entries and choose the first match.
-    :type fallback: boolean or iterable
     :return: the localized string
     :raise IndexError: If the language supports and requires more plurals
         than defined for the given PLURAL pattern.
@@ -561,6 +587,7 @@ def translate(code,
     if hasattr(code, 'code'):
         family = code.family.name
         code = code.code
+    assert isinstance(code, str)
 
     try:
         lookup = xdict[code]
@@ -581,6 +608,7 @@ def translate(code,
         if fallback is True:
             codes += _altlang(code) + ['_default', 'en']
         elif fallback is not False:
+            assert not isinstance(fallback, bool)
             codes.extend(fallback)
         for code in codes:
             if code in lookup:
@@ -593,7 +621,7 @@ def translate(code,
             trans = None
 
     if trans is None:
-        if 'wikipedia' in xdict:
+        if isinstance(xdict, dict) and 'wikipedia' in xdict:
             # fallback to wikipedia family
             return translate(code, xdict['wikipedia'],
                              parameters=parameters, fallback=fallback)
@@ -616,10 +644,11 @@ def translate(code,
     return trans
 
 
-@deprecated_args(code='source')
-def twtranslate(source,
+def twtranslate(source: STR_OR_SITE_TYPE,
                 twtitle: str,
-                parameters: Optional[Mapping] = None, *,
+                parameters: Union[Sequence[str], Mapping[str, int],
+                                  None] = None,
+                *,
                 fallback: bool = True,
                 fallback_prompt: Optional[str] = None,
                 only_plural: bool = False) -> Optional[str]:
@@ -676,7 +705,6 @@ def twtranslate(source,
 
     :param source: When it's a site it's using the lang attribute and otherwise
         it is using the value directly.
-    :type source: BaseSite or str
     :param twtitle: The TranslateWiki string title, in <package>-<key> format
     :param parameters: For passing parameters. It should be a mapping but for
         backwards compatibility can also be a list, tuple or a single value.
@@ -741,8 +769,7 @@ def twtranslate(source,
     return trans
 
 
-@deprecated_args(code='source')
-def twhas_key(source, twtitle: str) -> bool:
+def twhas_key(source: STR_OR_SITE_TYPE, twtitle: str) -> bool:
     """
     Check if a message has a translation in the specified language code.
 
@@ -753,7 +780,6 @@ def twhas_key(source, twtitle: str) -> bool:
 
     :param source: When it's a site it's using the lang attribute and otherwise
         it is using the value directly.
-    :type source: BaseSite or str
     :param twtitle: The TranslateWiki string title, in <package>-<key> format
     """
     # If a site is given instead of a code, use its language
@@ -772,7 +798,7 @@ def twget_keys(twtitle: str) -> List[str]:
     """
     # obtain the directory containing all the json files for this package
     package = twtitle.split('-')[0]
-    mod = __import__(_messages_package_name, fromlist=[str('__file__')])
+    mod = __import__(_messages_package_name, fromlist=['__file__'])
     pathname = os.path.join(next(iter(mod.__path__)), package)
 
     # build a list of languages in that directory
@@ -786,8 +812,36 @@ def twget_keys(twtitle: str) -> List[str]:
             if lang != 'qqq' and _get_translation(lang, twtitle)]
 
 
+def bundles(stem: bool = False) -> Generator[Union[Path, str], None, None]:
+    """A generator which yields message bundle names or its path objects.
+
+    :param stem: yield the Path.stem if True and the Path object otherwise
+
+    .. versionadded:: 7.0
+    """
+    for dirpath in Path(*_messages_package_name.split('.')).iterdir():
+        if dirpath.is_dir() and not dirpath.match('*__'):  # ignore cache
+            if stem:
+                yield dirpath.stem
+            else:
+                yield dirpath
+
+
+def known_languages() -> List[str]:
+    """All languages we have localizations for.
+
+    .. versionadded:: 7.0
+    """
+    langs = set()
+    for dirpath in bundles():
+        for fname in dirpath.iterdir():
+            if fname.suffix == '.json':
+                langs.add(fname.stem)
+    return sorted(langs)
+
+
 def input(twtitle: str,
-          parameters: Optional[Mapping] = None,
+          parameters: Optional[Mapping[str, int]] = None,
           password: bool = False,
           fallback_prompt: Optional[str] = None) -> str:
     """
@@ -813,8 +867,5 @@ def input(twtitle: str,
     return pywikibot.input(prompt, password)
 
 
-wrapper = ModuleDeprecationWrapper(__name__)
-wrapper.add_deprecated_attr(
-    'TranslationError',
-    replacement_name='pywikibot.exceptions.TranslationError',
-    since='20210423')
+if not messages_available():
+    set_messages_package('pywikibot.scripts.i18n')
