@@ -35,6 +35,7 @@ from typing import Any
 from pywikibot.backports import Callable, List
 from pywikibot.tools import deprecated_args, issue_deprecation_warning
 
+
 STDOUT = 16  #:
 VERBOSE = 18  #:
 INPUT = 25  #:
@@ -87,7 +88,7 @@ def logoutput(msg: Any,
     the log message to include an exception traceback.
 
     :param msg: The message to be printed.
-    :param args: Not used yet; prevents positinal arguments except `msg`.
+    :param args: Not used yet; prevents positional arguments except `msg`.
     :param level: The logging level; supported by :func:`logoutput` only.
     :keyword newline: If newline is True (default), a line feed will be
         added after printing the msg.
@@ -95,7 +96,7 @@ def logoutput(msg: Any,
     :keyword layer: Suffix of the logger name separated by dot. By
         default no suffix is used.
     :type layer: str
-    :keyword decoder: If msg is bytes, this decoder is used to deccode.
+    :keyword decoder: If msg is bytes, this decoder is used to decode.
         Default is 'utf-8', fallback is 'iso8859-1'
     :type decoder: str
     :param kwargs: For the other keyword arguments refer
@@ -170,7 +171,7 @@ def info(msg: Any = '', *args: Any, **kwargs: Any) -> None:
 
 
 output = info
-"""Synomym for :func:`info` for backward compatibility. The arguments
+"""Synonym for :func:`info` for backward compatibility. The arguments
 are interpreted as for :func:`logoutput`.
 
 .. versionchanged:: 7.2
@@ -189,13 +190,13 @@ def stdout(msg: Any = '', *args: Any, **kwargs: Any) -> None:
 
     ``msg`` will be sent to standard output (stdout) via
     :mod:`pywikibot.userinterfaces`, so that it can be piped to another
-    process. All other functions will sent to stderr.
+    process. All other functions will send to stderr.
     `msg` may be omitted and a newline is printed in that case.
 
     The arguments are interpreted as for :func:`logoutput`.
 
     .. versionchanged:: 7.2
-       `text`was renamed to `msg`; `msg` paramerer may be omitted;
+       `text`was renamed to `msg`; `msg` parameter may be omitted;
        only keyword arguments are allowed except for `msg`.
     .. seealso::
        - :python:`Logger.log()<library/logging.html#logging.Logger.log>`
@@ -290,25 +291,26 @@ def debug(msg: Any, *args: Any, **kwargs: Any) -> None:
 
 # Note: The logoutput frame must be updated if this decorator is removed
 @deprecated_args(tb='exc_info')  # since 7.2
-def exception(msg: Any = None, *args: Any, **kwargs: Any) -> None:
+def exception(msg: Any = None, *args: Any,
+              exc_info: bool = True, **kwargs: Any) -> None:
     """Output an error traceback to the user with level :const:`ERROR`.
 
     Use directly after an 'except' statement::
 
         ...
         except Exception:
-            pywikibot.exception('exc_info'=True)
+            pywikibot.exception()
         ...
 
     or alternatively::
 
         ...
         except Exception as e:
-            pywikibot.exception(e, 'exc_info'=True)
+            pywikibot.exception(e)
         ...
 
-    Without `exc_info` parameter this function works like :func:`error`
-    except that the `msg` parameter may be omitted.
+    With `exc_info=False` this function works like :func:`error` except
+    that the `msg` parameter may be omitted.
     This function should only be called from an Exception handler.
     ``msg`` will be sent to stderr via :mod:`pywikibot.userinterfaces`.
     The arguments are interpreted as for :func:`logoutput`.
@@ -316,6 +318,8 @@ def exception(msg: Any = None, *args: Any, **kwargs: Any) -> None:
     .. versionchanged:: 7.2
        only keyword arguments are allowed except for `msg`;
        `exc_info` keyword is to be used instead of `tb`.
+    .. versionchanged:: 7.3
+       `exc_info` is True by default
     .. seealso::
        :python:`Logger.exception()
        <library/logging.html#logging.Logger.exception>`
@@ -325,7 +329,7 @@ def exception(msg: Any = None, *args: Any, **kwargs: Any) -> None:
     if msg is None:
         exc_type, value, _tb = sys.exc_info()
         msg = str(value)
-        if not kwargs.get('exc_info', False):
+        if not exc_info:
             msg += ' ({})'.format(exc_type.__name__)
     assert msg is not None
-    error(msg, *args, **kwargs)
+    error(msg, *args, exc_info=exc_info, **kwargs)
