@@ -1,5 +1,5 @@
 #!/usr/bin/python3
-"""Script to create user-config.py.
+"""Script to create user-config.py. Other file names are not supported.
 
 .. versionchanged:: 7.0
    moved to pywikibot.scripts folder
@@ -129,7 +129,7 @@ def get_site_and_lang(
     if hasattr(fam, 'langs'):
         if hasattr(fam, 'languages_by_size'):
             by_size = [code for code in fam.languages_by_size
-                       if code in fam.langs.keys()]
+                       if code in fam.langs]
         else:
             by_size = []
         known_langs = by_size + sorted(
