@@ -4,8 +4,8 @@
 
 This wrapper script invokes script by its name in this search order:
 
-1. Scripts listed in `user_script_paths` list inside your `user-config.py`
-   settings file in the given order. Refer
+1. Scripts listed in `user_script_paths` list inside your user config
+   settings file (usually `user-config.py`) in the given order. Refer
    :ref:`External Script Path Settings`.
 2. User scripts residing in `scripts/userscripts` (directory mode only).
 3. Scripts residing in `scripts` folder (directory mode only).
@@ -27,12 +27,14 @@ This wrapper script uses the package directory to store all user files,
 will fix up search paths so the package does not need to be installed, etc.
 
 Currently, `<pwb options>` are :ref:`global options`. This can be used
-for tests to set the default site (see T216825)::
+for tests to set the default site (see :phab:`T216825`)::
 
     python pwb.py -lang:de bot_tests -v
 
 .. versionchanged:: 7.0
    pwb wrapper was added to the Python site package lib
+.. versionchanged:: 7.7
+   pwb wrapper is able to set ``PYWIKIBOT_TEST_...`` environment variables
 """
 # (C) Pywikibot team, 2012-2022
 #
@@ -52,10 +54,8 @@ from warnings import warn
 
 try:
     from pathlib import Path
-except ImportError as e:
-    from setup import PYTHON_VERSION, VERSIONS_REQUIRED_MESSAGE
-    print(VERSIONS_REQUIRED_MESSAGE.format(version=PYTHON_VERSION))
-    sys.exit(e)
+except ImportError:
+    pass
 
 pwb = None
 site_package = False
@@ -111,6 +111,9 @@ def check_pwb_versions(package):
 def run_python_file(filename, args, package=None):
     """Run a python file as if it were the main program on the command line.
 
+    .. versionchanged:: 7.7
+       Set and restore ``PYWIKIBOT_TEST_...`` environment variables.
+
     :param filename: The path to the file to execute, it need not be a
         .py file.
     :type filename: str
@@ -133,6 +136,11 @@ def run_python_file(filename, args, package=None):
     old_argv = sys.argv
     old_argvu = pwb.argvu
 
+    # set environment values
+    old_env = os.environ.copy()
+    for key, value in environ:
+        os.environ[key] = value
+
     sys.argv = [filename] + args
     pwb.argvu = [Path(filename).stem] + args
     sys.path.insert(0, os.path.dirname(filename))
@@ -153,27 +161,44 @@ def run_python_file(filename, args, package=None):
 
 # end of snippet from coverage
 
+        # Restore environment values
+        for key, value in environ:
+            if key in old_env:
+                os.environ[key] = old_env[key]
+            else:
+                del os.environ[key]
+
 
 def handle_args(pwb_py, *args):
     """Handle args and get filename.
 
-    :return: filename, script args, local args for pwb.py
-    :rtype: tuple
+    .. versionchanged:: 7.7
+       Catch ``PYWIKIBOT_TEST_...`` environment variables.
+
+    :return: filename, script args, local pwb args, environment variables
+    :rtype: Tuple[str, List[str], List[str], [List[str]]
     """
     fname = None
-    index = 0
-    for arg in args:
+    local = []
+    env = []
+    for index, arg in enumerate(args, start=1):
         if arg in ('-version', '--version'):
             fname = 'version.py'
         elif arg.startswith('-'):
-            index += 1
-            continue
+            local.append(arg)
+        elif arg.startswith('PYWIKIBOT_TEST_'):
+            var, _, val = arg.partition('=')
+            env.append((var, val or '1'))
         else:
             fname = arg
             if not fname.endswith('.py'):
                 fname += '.py'
-        break
-    return fname, list(args[index + int(bool(fname)):]), args[:index]
+        if fname:
+            break
+    else:
+        index = 0
+
+    return fname, list(args[index:]), local, env
 
 
 def _print_requirements(requirements, script, variant):  # pragma: no cover
@@ -260,24 +285,29 @@ def check_modules(script=None):
     return not missing_requirements
 
 
-filename, script_args, global_args = handle_args(*sys.argv)
+filename, script_args, global_args, environ = handle_args(*sys.argv)
 
-# Search for user-config.py before creating one.
-# If successful, user-config.py already exists in one of the candidate
+# Search for user config file (user-config.py) before creating one.
+# If successful, user config file already exists in one of the candidate
 # directories. See config.py for details on search order.
 # Use env var to communicate to config.py pwb.py location (bug T74918).
 _pwb_dir = os.path.split(__file__)[0]
 os.environ['PYWIKIBOT_DIR_PWB'] = _pwb_dir
 try:
     import pywikibot as pwb
-except RuntimeError:  # pragma: no cover
+except RuntimeError as e:  # pragma: no cover
     os.environ['PYWIKIBOT_NO_USER_CONFIG'] = '2'
     import pywikibot as pwb
 
-    # user-config.py to be created
+    # user config file to be created
     if filename is not None and not (filename.startswith('generate_')
                                      or filename == 'version.py'):
-        print("NOTE: 'user-config.py' was not found!")
+        from pywikibot.config import user_config_file
+        if user_config_file != 'user-config.py':
+            # do not create a user config file if name is not default
+            sys.exit(e)
+
+        print('NOTE: user-config.py was not found!')
         print('Please follow the prompts to create it:')
         run_python_file(os.path.join(
             _pwb_dir, 'pywikibot', 'scripts', 'generate_user_files.py'), [])
@@ -287,11 +317,13 @@ except RuntimeError:  # pragma: no cover
         sys.exit(1)
 except ImportError as e:  # raised in textlib
     sys.exit(e)
+except SyntaxError as e:  # pragma: no cover
+    sys.exit(str(e) + '\nProbably outdated Python version')
 
 
 def find_alternates(filename, script_paths):
     """Search for similar filenames in the given script paths."""
-    from pywikibot import config, input_choice, info
+    from pywikibot import config, input_choice, error, info, warning
     from pywikibot.bot import QuitKeyboardInterrupt, ShowingListOption
 
     assert config.pwb_close_matches > 0, \
@@ -299,14 +331,17 @@ def find_alternates(filename, script_paths):
     assert 0.0 < config.pwb_cut_off < 1.0, \
         'config.pwb_cut_off must be a float in range [0, 1]'
 
-    print('ERROR: {} not found! Misspelling?'.format(filename),
-          file=sys.stderr)
+    error('{} not found! Misspelling?'.format(filename))
 
     scripts = {}
 
     script_paths = [['.']] + script_paths  # add current directory
     for path in script_paths:
         folder = Path(_pwb_dir).joinpath(*path)
+        if not folder.exists():  # pragma: no cover
+            warning('{} does not exists; remove it from user_script_paths'
+                    .format(folder))
+            continue
         for script_name in folder.iterdir():
             name, suffix = script_name.stem, script_name.suffix
             if suffix == '.py' and not name.startswith('__'):
@@ -467,6 +502,8 @@ def main():
     # setup.py may also raise RuntimeError
     except RuntimeError as e:  # pragma: no cover
         sys.exit(e)
+    except SyntaxError as e:  # pragma: no cover
+        sys.exit(str(e) + '\nProbably outdated Python version')
 
     if not execute():
         print(__doc__)
