@@ -8,7 +8,7 @@ import datetime
 import json
 import uuid
 from contextlib import suppress
-from typing import Optional
+from typing import Any, Dict, List, Optional
 from warnings import warn
 
 import pywikibot
@@ -22,7 +22,8 @@ from pywikibot.exceptions import (
 )
 from pywikibot.site._apisite import APISite
 from pywikibot.site._decorators import need_extension, need_right, need_version
-from pywikibot.tools import itergroup, merge_unique_dicts, remove_last_args
+from pywikibot.tools import merge_unique_dicts, remove_last_args
+from pywikibot.tools.itertools import itergroup
 
 
 __all__ = ('DataSite', )
@@ -247,11 +248,11 @@ class DataSite(APISite):
 
     @need_right('edit')
     def editEntity(self, entity, data, bot: bool = True, **kwargs):
-        """
-        Edit entity.
+        """Edit entity.
 
-        Note: This method is unable to create entities other than 'item'
-        if dict with API parameters was passed to 'entity' parameter.
+        .. note:: This method is unable to create entities other than
+           'item' if dict with API parameters was passed to 'entity'
+           parameter.
 
         :param entity: Page to edit, or dict with API parameters
             to use for entity identification
@@ -298,17 +299,18 @@ class DataSite(APISite):
         return req.submit()
 
     @need_right('edit')
-    def addClaim(self, entity, claim, bot: bool = True, summary=None) -> None:
+    def addClaim(self,
+                 entity: 'pywikibot.page.WikibaseEntity',
+                 claim: 'pywikibot.page.Claim',
+                 bot: bool = True,
+                 summary: Optional[str] = None) -> None:
         """
         Add a claim.
 
         :param entity: Entity to modify
-        :type entity: WikibaseEntity
         :param claim: Claim to be added
-        :type claim: pywikibot.Claim
         :param bot: Whether to mark the edit as a bot edit
         :param summary: Edit summary
-        :type summary: str
         """
         claim.snak = entity.getID() + '$' + str(uuid.uuid4())
         params = {'action': 'wbsetclaim',
@@ -358,15 +360,15 @@ class DataSite(APISite):
         return req.submit()
 
     @need_right('edit')
-    def save_claim(self, claim, summary=None, bot: bool = True):
+    def save_claim(self, claim: 'pywikibot.page.Claim',
+                   summary: Optional[str] = None,
+                   bot: bool = True):
         """
         Save the whole claim to the wikibase site.
 
         :param claim: The claim to save
-        :type claim: pywikibot.Claim
         :param bot: Whether to mark the edit as a bot edit
         :param summary: Edit summary
-        :type summary: str
         """
         if claim.isReference or claim.isQualifier:
             raise NotImplementedError
@@ -420,14 +422,12 @@ class DataSite(APISite):
         snak = {}
         for sourceclaim in sources:
             datavalue = sourceclaim._formatDataValue()
-            valuesnaks = []
-            if sourceclaim.getID() in snak:
-                valuesnaks = snak[sourceclaim.getID()]
-            valuesnaks.append({'snaktype': 'value',
-                               'property': sourceclaim.getID(),
-                               'datavalue': datavalue,
-                               },
-                              )
+            valuesnaks = snak.get(sourceclaim.getID(), [])
+            valuesnaks.append({
+                'snaktype': 'value',
+                'property': sourceclaim.getID(),
+                'datavalue': datavalue,
+            })
 
             snak[sourceclaim.getID()] = valuesnaks
             # set the hash if the source should be changed.
@@ -654,7 +654,7 @@ class DataSite(APISite):
         }
         if bot:
             params['bot'] = 1
-        req = self._simple_request(**params)
+        req = self.simple_request(**params)
         data = req.submit()
         return data
 
@@ -712,41 +712,104 @@ class DataSite(APISite):
                               total=total, parameters=parameters)
         return gen
 
+    def parsevalue(self, datatype: str, values: List[str],
+                   options: Optional[Dict[str, Any]] = None,
+                   language: Optional[str] = None,
+                   validate: bool = False) -> List[Any]:
+        """
+        Send data values to the wikibase parser for interpretation.
+
+        .. versionadded:: 7.5
+        .. seealso:: `wbparsevalue API
+           <https://www.wikidata.org/w/api.php?action=help&modules=wbparsevalue>`_
+
+        :param datatype: datatype of the values being parsed. Refer the
+            API for a valid datatype.
+        :param values: list of values to be parsed
+        :param options: any additional options for wikibase parser
+            (for time, 'precision' should be specified)
+        :param language: code of the language to parse the value in
+        :param validate: whether parser should provide data validation as well
+            as parsing
+        :return: list of parsed values
+        :raises ValueError: parsing failed due to some invalid input values
+        """
+        params = {
+            'action': 'wbparsevalue',
+            'datatype': datatype,
+            'values': values,
+            'options': json.dumps(options or {}),
+            'validate': validate,
+            'uselang': language or 'en',
+        }
+        req = self.simple_request(**params)
+        try:
+            data = req.submit()
+        except APIError as e:
+            if e.code.startswith('wikibase-parse-error'):
+                for err in e.other['results']:
+                    if 'error' in err:
+                        pywikibot.error('{error-info} for value {raw!r}, '
+                                        '{expected-format!r} format expected'
+                                        .format_map(err))
+                raise ValueError(e) from None
+            raise
+
+        if 'results' not in data:
+            raise RuntimeError("Unexpected missing 'results' in query data\n{}"
+                               .format(data))
+
+        results = []
+        for result_hash in data['results']:
+            if 'value' not in result_hash:
+                # There should be an APIError occurred already
+                raise RuntimeError("Unexpected missing 'value' in query data:"
+                                   '\n{}'.format(result_hash))
+            results.append(result_hash['value'])
+        return results
+
     @need_right('edit')
-    def _wbset_action(self, itemdef, action, action_data, **kwargs):
+    def _wbset_action(self, itemdef, action: str, action_data,
+                      **kwargs) -> dict:
         """
         Execute wbset{action} on a Wikibase entity.
 
         Supported actions are:
             wbsetaliases, wbsetdescription, wbsetlabel and wbsetsitelink
 
+        wbsetaliases:
+            dict shall have the following structure:
+
+            .. code-block::
+
+               {
+                   'language': value (str),
+                   'add': list of language codes (str),
+                   'remove': list of language codes (str),
+                   'set' list of language codes (str)
+                }
+
+            'add' and 'remove' are alternative to 'set'
+
+        wbsetdescription and wbsetlabel:
+            dict shall have keys 'language', 'value'
+
+        wbsetsitelink:
+            dict shall have keys 'linksite', 'linktitle' and
+            optionally 'badges'
+
         :param itemdef: Entity to modify or create
         :type itemdef: str, WikibaseEntity or Page connected to such item
         :param action: wbset{action} to perform:
             'wbsetaliases', 'wbsetdescription', 'wbsetlabel', 'wbsetsitelink'
-        :type action: str
-        :param data: data to be used in API request, see API help
-        :type data: SiteLink or dict
-            wbsetaliases:
-                dict shall have the following structure:
-                {'language': value (str),
-                 'add': list of language codes (str),
-                 'remove': list of language codes (str),
-                 'set' list of language codes (str)
-                  }
-                'add' and 'remove' are alternative to 'set'
-            wbsetdescription and wbsetlabel:
-                dict shall have keys 'language', 'value'
-            wbsetsitelink:
-                dict shall have keys 'linksite', 'linktitle' and
-                optionally 'badges'
-        @kwargs bot: Whether to mark the edit as a bot edit, default is True
+        :param action_data: data to be used in API request, see API help
+        :type action_data: SiteLink or dict
+        :keyword bot: Whether to mark the edit as a bot edit, default is True
         :type bot: bool
-        @kwargs tags: Change tags to apply with the edit
+        :keyword tags: Change tags to apply with the edit
         :type tags: list of str
         :return: query result
-        :rtype: dict
-        :raises AssertionError, TypeError
+        :raises: AssertionError, TypeError
         """
         def format_sitelink(sitelink):
             """Convert SiteLink to a dict accepted by wbsetsitelink API."""
@@ -769,8 +832,8 @@ class DataSite(APISite):
                 assert keys < {'language', 'add', 'remove', 'set'}
                 assert 'language' in keys
                 assert ({'add', 'remove', 'set'} & keys)
-                assert not ({'add', 'set'} < keys)
-                assert not ({'remove', 'set'} < keys)
+                assert ({'add', 'set'} >= keys)
+                assert ({'remove', 'set'} >= keys)
             elif action in ('wbsetlabel', 'wbsetdescription'):
                 res = data
                 keys = set(res)
@@ -881,7 +944,7 @@ class DataSite(APISite):
         }
         if baserevid:
             params['baserevid'] = baserevid
-        req = self._simple_request(**params)
+        req = self.simple_request(**params)
         data = req.submit()
         return data
 
@@ -906,7 +969,7 @@ class DataSite(APISite):
         }
         if baserevid:
             params['baserevid'] = baserevid
-        req = self._simple_request(**params)
+        req = self.simple_request(**params)
         data = req.submit()
         return data
 
@@ -936,6 +999,6 @@ class DataSite(APISite):
         }
         if baserevid:
             params['baserevid'] = baserevid
-        req = self._simple_request(**params)
+        req = self.simple_request(**params)
         data = req.submit()
         return data
