@@ -1,20 +1,21 @@
 """Decorators used by site models."""
 #
-# (C) Pywikibot team, 2008-2021
+# (C) Pywikibot team, 2008-2022
 #
 # Distributed under the terms of the MIT license.
 #
+from typing import Optional
+
 from pywikibot.exceptions import UnknownExtensionError, UserRightsError
 from pywikibot.tools import MediaWikiVersion, manage_wrapping
 
 
-def must_be(group=None):
+def must_be(group: Optional[str] = None):
     """Decorator to require a certain user status when method is called.
 
     :param group: The group the logged in user should belong to.
                   This parameter can be overridden by
                   keyword argument 'as_group'.
-    :type group: str or None
     :return: method decorator
     :raises UserRightsError: user is not part of the required user group.
     """
@@ -68,11 +69,10 @@ def need_extension(extension: str):
     return decorator
 
 
-def need_right(right=None):
+def need_right(right: Optional[str] = None):
     """Decorator to require a certain user right when method is called.
 
     :param right: The right the logged in user should have.
-    :type right: str or None
     :return: method decorator
     :raises UserRightsError: user has insufficient rights.
     """
@@ -81,8 +81,8 @@ def need_right(right=None):
             if self.obsolete:
                 if not self.has_group('steward'):
                     raise UserRightsError(
-                        'Site {} has been closed. Only steward '
-                        'can perform requested action.'
+                        'Site {} has been closed. Only stewards '
+                        'can perform the requested action.'
                         .format(self.sitename))
 
             elif right is not None and not self.has_right(right):
