@@ -86,12 +86,15 @@ class ProofreadPageMixin:
         The following info is returned by the query and cached:
         - self._proofread_index_ns: Index Namespace
         - self._proofread_page_ns: Page Namespace
-        - self._proofread_levels: a dictionary with:
-                keys: int in the range [0, 1, ..., 4]
-                values: category name corresponding to the 'key' quality level
+        - self._proofread_levels: a dictionary with::
+
+            keys: int in the range [0, 1, ..., 4]
+            values: category name corresponding to the 'key' quality level
             e.g. on en.wikisource:
-            {0: 'Without text', 1: 'Not proofread', 2: 'Problematic',
-             3: 'Proofread', 4: 'Validated'}
+
+            .. code-block::
+                {0: 'Without text', 1: 'Not proofread', 2: 'Problematic',
+                 3: 'Proofread', 4: 'Validated'}
 
         :param expiry: either a number of days or a datetime.timedelta object
         :type expiry: int (days), :py:obj:`datetime.timedelta`, False (config)
@@ -395,7 +398,7 @@ class FlowMixin:
         :param toconly: Whether to only include information for the TOC.
         :type toconly: bool
         :param offset: The timestamp to start at (when sortby is 'updated').
-        :type offset: Timestamp or equivalent str
+        :type offset: time.Timestamp or equivalent str
         :param offset_id: The topic UUID to start at (when sortby is 'newest').
         :type offset_id: str (in the form of a UUID)
         :param reverse: Whether to reverse the topic ordering.
@@ -746,17 +749,17 @@ class TextExtractsMixin:
 
            - https://www.mediawiki.org/wiki/Extension:TextExtracts
 
-           - :meth:`pywikibot.page.BasePage.extract`.
+           - :meth:`page.BasePage.extract`.
         """
         if not page.exists():
             raise NoPageError(page)
-        req = self._simple_request(action='query',
-                                   prop='extracts',
-                                   titles=page.title(with_section=False),
-                                   exchars=chars,
-                                   exsentences=sentences,
-                                   exintro=intro,
-                                   explaintext=plaintext)
+        req = self.simple_request(action='query',
+                                  prop='extracts',
+                                  titles=page.title(with_section=False),
+                                  exchars=chars,
+                                  exsentences=sentences,
+                                  exintro=intro,
+                                  explaintext=plaintext)
         data = req.submit()['query']['pages']
         if '-1' in data:
             msg = data['-1'].get('invalidreason',
