@@ -25,12 +25,8 @@ from pywikibot.exceptions import (
 )
 from pywikibot.site._decorators import need_right, need_version
 from pywikibot.site._namespace import NamespaceArgType
-from pywikibot.tools import (
-    filter_unique,
-    is_ip_address,
-    issue_deprecation_warning,
-    itergroup,
-)
+from pywikibot.tools import is_ip_address, issue_deprecation_warning
+from pywikibot.tools.itertools import filter_unique, itergroup
 
 
 class GeneratorsMixin:
@@ -97,13 +93,20 @@ class GeneratorsMixin:
         groupsize: int = 50,
         templates: bool = False,
         langlinks: bool = False,
-        pageprops: bool = False
+        pageprops: bool = False,
+        categories: bool = False,
+        content: bool = True
     ):
         """Return a generator to a list of preloaded pages.
 
         Pages are iterated in the same order than in the underlying pagelist.
         In case of duplicates in a groupsize batch, return the first entry.
 
+        .. versionchanged:: 7.6
+           *content* parameter was added.
+        .. versionchanged:: 7.7
+           *categories* parameter was added.
+
         :param pagelist: an iterable that returns Page objects
         :param groupsize: how many Pages to query at a time
         :param templates: preload pages (typically templates) transcluded in
@@ -111,6 +114,8 @@ class GeneratorsMixin:
         :param langlinks: preload all language links from the provided pages
             to other languages
         :param pageprops: preload various properties defined in page content
+        :param categories: preload page categories
+        :param content: preload page content
         """
         props = 'revisions|info|categoryinfo'
         if templates:
@@ -119,6 +124,8 @@ class GeneratorsMixin:
             props += '|langlinks'
         if pageprops:
             props += '|pageprops'
+        if categories:
+            props += '|categories'
 
         for sublist in itergroup(pagelist, min(groupsize, self.maxlimit)):
             # Do not use p.pageid property as it will force page loading.
@@ -144,7 +151,7 @@ class GeneratorsMixin:
                 rvgen.request['pageids'] = set(pageids)
             else:
                 rvgen.request['titles'] = list(cache.keys())
-            rvgen.request['rvprop'] = self._rvprops(content=True)
+            rvgen.request['rvprop'] = self._rvprops(content=content)
             pywikibot.output('Retrieving {} pages from {}.'
                              .format(len(cache), self))
 
@@ -168,11 +175,13 @@ class GeneratorsMixin:
                                 'preloadpages: Query returned unexpected '
                                 "title '{}'".format(pagedata['title']))
                             continue
+
                 except KeyError:
                     pywikibot.debug("No 'title' in {}".format(pagedata))
                     pywikibot.debug('pageids={}'.format(pageids))
                     pywikibot.debug('titles={}'.format(list(cache.keys())))
                     continue
+
                 priority, page = cache[pagedata['title']]
                 api.update_page(page, pagedata, rvgen.props)
                 priority, page = heapq.heappushpop(prio_queue,
@@ -484,7 +493,7 @@ class GeneratorsMixin:
             (default False)
         :param starttime: if provided, only generate pages added after this
             time; not valid unless sortby="timestamp"
-        :type starttime: pywikibot.Timestamp
+        :type starttime: time.Timestamp
         :param endtime: if provided, only generate pages added before this
             time; not valid unless sortby="timestamp"
         :param startprefix: if provided, only generate pages >= this title
@@ -694,8 +703,10 @@ class GeneratorsMixin:
                 raise ValueError(
                     'loadrevisions: endid > startid with rvdir=False')
 
-        rvargs = {'type_arg': 'info|revisions'}
-        rvargs['rvprop'] = self._rvprops(content=content)
+        rvargs = {
+            'type_arg': 'info|revisions',
+            'rvprop': self._rvprops(content=content),
+        }
 
         if content and section is not None:
             rvargs['rvsection'] = str(section)
@@ -1097,16 +1108,16 @@ class GeneratorsMixin:
 
         .. seealso:: :api:`Blocks`
 
-        .. note::
-           logevents only logs user blocks, while this method iterates
-           all blocks including IP ranges.
+        .. note:: logevents only logs user blocks,
+           while this method iterates all blocks
+           including IP ranges.
         .. warning::
            ``iprange`` parameter cannot be used together with ``users``.
 
         :param starttime: start iterating at this Timestamp
-        :type starttime: pywikibot.Timestamp
+        :type starttime: time.Timestamp
         :param endtime: stop iterating at this Timestamp
-        :type endtime: pywikibot.Timestamp
+        :type endtime: time.Timestamp
         :param reverse: if True, iterate oldest blocks first (default: newest)
         :param blockids: only iterate blocks with these id numbers. Numbers
             must be separated by '|' if given by a str.
@@ -1226,8 +1237,7 @@ class GeneratorsMixin:
 
         .. seealso:: :api:`Logevents`
 
-        .. note::
-           logevents with `logtype='block'` only logs user blocks
+        .. note:: logevents with `logtype='block'` only logs user blocks
            whereas `site.blocks` iterates all blocks including IP ranges.
 
         :param logtype: only iterate entries of this type
@@ -1237,13 +1247,16 @@ class GeneratorsMixin:
         :type page: pywikibot.Page or str
         :param namespace: namespace(s) to retrieve logevents from
         :type namespace: int or Namespace or an iterable of them
-        :note: due to an API limitation, if namespace param contains multiple
-            namespaces, log entries from all namespaces will be fetched from
-            the API and will be filtered later during iteration.
+
+        .. note:: due to an API limitation,
+           if namespace param contains multiple namespaces,
+           log entries from all namespaces will be fetched from
+           the API and will be filtered later during iteration.
+
         :param start: only iterate entries from and after this Timestamp
-        :type start: Timestamp or ISO date string
+        :type start: time.Timestamp or ISO date string
         :param end: only iterate entries up to and through this Timestamp
-        :type end: Timestamp or ISO date string
+        :type end: time.Timestamp or ISO date string
         :param reverse: if True, iterate oldest entries first (default: newest)
         :param tag: only iterate entries tagged with this tag
         :param total: maximum number of events to iterate
@@ -1548,7 +1561,7 @@ class GeneratorsMixin:
             or typing.Iterable[str]
         :keyword revids: Get revisions by their ID
 
-        :note: either titles or revids must be set but not both
+        .. note:: either titles or revids must be set but not both
 
         :param start: Iterate revisions starting at this Timestamp
         :param end: Iterate revisions ending at this Timestamp
@@ -1748,8 +1761,6 @@ class GeneratorsMixin:
                                namespaces=namespaces, total=total,
                                g_content=content, **params)
 
-    # TODO: implement undelete
-
     _patrol_errors = {
         'nosuchrcid': 'There is no change with rcid {rcid}',
         'nosuchrevid': 'There is no change with revid {revid}',
