@@ -1,9 +1,10 @@
 """Objects representing api tokens."""
 #
-# (C) Pywikibot team, 2008-2020
+# (C) Pywikibot team, 2008-2022
 #
 # Distributed under the terms of the MIT license.
 #
+from pywikibot import debug
 from pywikibot.exceptions import Error
 
 
@@ -11,7 +12,7 @@ class TokenWallet:
 
     """Container for tokens."""
 
-    def __init__(self, site):
+    def __init__(self, site) -> None:
         """Initializer.
 
         :type site: pywikibot.site.APISite
@@ -20,7 +21,7 @@ class TokenWallet:
         self._tokens = {}
         self.failed_cache = set()  # cache unavailable tokens.
 
-    def load_tokens(self, types, all=False):
+    def load_tokens(self, types, all: bool = False) -> None:
         """
         Preload one or multiple tokens.
 
@@ -28,7 +29,6 @@ class TokenWallet:
         :type types: iterable
         :param all: load all available tokens, if None only if it can be done
             in one request.
-        :type all: bool
         """
         if self.site.user() is None:
             self.site.login()
@@ -54,6 +54,14 @@ class TokenWallet:
         # always preload all for users without tokens
         failed_cache_key = (self.site.user(), key)
 
+        # redirect old tokens to be compatible with older MW version
+        # https://www.mediawiki.org/wiki/MediaWiki_1.37/Deprecation_of_legacy_API_token_parameters
+        if self.site.mw_version >= '1.24wmf19' \
+           and key in {'edit', 'delete', 'protect', 'move', 'block', 'unblock',
+                       'email', 'import', 'options'}:
+            debug('Token {!r} was replaced by {!r}'.format(key, 'csrf'))
+            key = 'csrf'
+
         try:
             key = self.site.validate_tokens([key])[0]
         except IndexError:
@@ -74,14 +82,14 @@ class TokenWallet:
             "Action '{}' is not allowed for user {} on {} wiki."
             .format(key, self.site.user(), self.site))
 
-    def __contains__(self, key):
+    def __contains__(self, key) -> bool:
         """Return True if the given token name is cached."""
         return key in self._tokens.setdefault(self.site.user(), {})
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return a str representation of the internal tokens dictionary."""
         return self._tokens.__str__()
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Return a representation of the internal tokens dictionary."""
         return self._tokens.__repr__()
