@@ -68,7 +68,7 @@ class UploadRobot(BaseBot):
             would be overwritten or another mistake would be risked. Set it to
             an array of warning codes to selectively ignore specific warnings.
         :param target_site: Set the site to upload to. If target site is not
-            given it's taken from user-config.py.
+            given it's taken from user config file (user_config.py).
         :type target_site: object
         :param aborts: List of the warning types to abort upload on. Set to
             True to abort on any warning.
@@ -113,7 +113,7 @@ class UploadRobot(BaseBot):
         self.force_if_shared = force_if_shared
 
         if config.upload_to_commons:
-            default_site = pywikibot.Site('commons:commons')
+            default_site = pywikibot.Site('commons')
         else:
             default_site = pywikibot.Site()
         self.target_site = target_site or default_site
@@ -401,8 +401,8 @@ class UploadRobot(BaseBot):
                and (not site.has_right('upload_by_url') or download):
                 try:
                     file_url = self.read_file_content(file_url)
-                except FatalServerError:
-                    pywikibot.exception()
+                except FatalServerError as e:
+                    pywikibot.error(e)
                     return None
 
             try:
@@ -418,20 +418,20 @@ class UploadRobot(BaseBot):
                         .format(site))
                 elif error.code == 'copyuploadbaddomain' and not download \
                         and '://' in file_url:
-                    pywikibot.exception()
+                    pywikibot.error(error)
                     pywikibot.output('Downloading the file and retry...')
                     download = True
                     continue
                 else:
-                    pywikibot.error('Upload error: ', exc_info=True)
+                    pywikibot.exception('Upload error: ')
             except Exception:
-                pywikibot.error('Upload error: ', exc_info=True)
+                pywikibot.exception('Upload error: ')
             else:
                 if success:
                     # No warning, upload complete.
                     pywikibot.output('Upload of {} successful.'
                                      .format(filename))
-                    self.counter['write'] += 1
+                    self.counter['upload'] += 1
                     return filename  # data['filename']
                 pywikibot.output('Upload aborted.')
             break
