@@ -10,7 +10,6 @@ and return a unicode string.
 #
 # Distributed under the terms of the MIT license.
 #
-import datetime
 import re
 from collections import OrderedDict, namedtuple
 from collections.abc import Sequence
@@ -25,7 +24,8 @@ from pywikibot.backports import Sequence as SequenceType
 from pywikibot.backports import Tuple
 from pywikibot.exceptions import InvalidTitleError, SiteDefinitionError
 from pywikibot.family import Family
-from pywikibot.tools import deprecated
+from pywikibot.time import TZoneFixedOffset
+from pywikibot.tools import ModuleDeprecationWrapper, deprecated
 from pywikibot.userinterfaces.transliteration import NON_LATIN_DIGITS
 
 
@@ -127,13 +127,16 @@ def to_local_digits(phrase: Union[str, int], lang: str) -> str:
     Be aware that this function only works for several languages, and that it
     returns an unchanged string if an unsupported language is given.
 
+    .. versionchanged:: 7.5
+       always return a string even `phrase` is an int.
+
     :param phrase: The phrase to convert to localized numerical
     :param lang: language code
     :return: The localized version
     """
     digits = NON_LATIN_DIGITS.get(lang)
+    phrase = str(phrase)
     if digits:
-        phrase = str(phrase)
         trans = str.maketrans('0123456789', digits)
         phrase = phrase.translate(trans)
     return phrase
@@ -819,7 +822,7 @@ def replace_links(text: str, replace, site: 'pywikibot.site.BaseSite') -> str:
 
         new_title = new_link.canonical_title()
         # Make correct langlink if needed
-        if not new_link.site == site:
+        if new_link.site != site:
             new_title = ':' + new_link.site.code + ':' + new_title
 
         if is_link:
@@ -938,7 +941,7 @@ def _extract_sections(text: str, headings) -> list:
 def extract_sections(
     text: str, site=None
 ) -> NamedTuple('_Content', [('header', str),  # noqa: F821
-                             ('body', List[Tuple[str, str]]),  # noqa: F821
+                             ('sections', List[Tuple[str, str]]),  # noqa: F821
                              ('footer', str)]):  # noqa: F821
     """
     Return section headings and contents found in text.
@@ -965,8 +968,8 @@ def extract_sections(
 
             result = extract_sections(text, site)
             result.header = "'''A''' is a thing."
-            result.body = [('== History of A ==', 'Some history...'),
-                           ('== Usage of A ==', 'Some usage...')]
+            result.sections = [('== History of A ==', 'Some history...'),
+                               ('== Usage of A ==', 'Some usage...')]
             result.footer = '[[Category:Things starting with A]]'
 
     .. versionadded:: 3.0
@@ -1055,8 +1058,7 @@ def getLanguageLinks(
         lang = lang.lower()
         # Check if it really is in fact an interwiki link to a known
         # language, or if it's e.g. a category tag or an internal link
-        if lang in fam.obsolete:
-            lang = fam.obsolete[lang]
+        lang = fam.obsolete.get(lang, lang)
         if lang in fam.langs:
             if '|' in pagetitle:
                 # ignore text after the pipe
@@ -1827,41 +1829,6 @@ def reformat_ISBNs(text: str, match_func) -> str:
 # Time parsing functionality (Archivebot)
 # ---------------------------------------
 
-class tzoneFixedOffset(datetime.tzinfo):
-
-    """
-    Class building tzinfo objects for fixed-offset time zones.
-
-    :param offset: a number indicating fixed offset in minutes east from UTC
-    :param name: a string with name of the timezone
-    """
-
-    def __init__(self, offset: int, name: str) -> None:
-        """Initializer."""
-        self.__offset = datetime.timedelta(minutes=offset)
-        self.__name = name
-
-    def utcoffset(self, dt):
-        """Return the offset to UTC."""
-        return self.__offset
-
-    def tzname(self, dt):
-        """Return the name of the timezone."""
-        return self.__name
-
-    def dst(self, dt):
-        """Return no daylight savings time."""
-        return datetime.timedelta(0)
-
-    def __repr__(self) -> str:
-        """Return the internal representation of the timezone."""
-        return '{}({}, {})'.format(
-            self.__class__.__name__,
-            self.__offset.days * 86400 + self.__offset.seconds,
-            self.__name
-        )
-
-
 class TimeStripper:
 
     """Find timestamp in page and return it as pywikibot.Timestamp object."""
@@ -1927,7 +1894,7 @@ class TimeStripper:
         self._wikilink_pat = re.compile(
             r'\[\[(?P<link>[^\]\|]*?)(?P<anchor>\|[^\]]*)?\]\]')
 
-        self.tzinfo = tzoneFixedOffset(self.site.siteinfo['timeoffset'],
+        self.tzinfo = TZoneFixedOffset(self.site.siteinfo['timeoffset'],
                                        self.site.siteinfo['timezone'])
 
     @staticmethod
@@ -1948,8 +1915,8 @@ class TimeStripper:
         """
         m = None
         cnt = 0
-        for m in pat.finditer(txt):
-            cnt += 1
+        for cnt, m in enumerate(pat.finditer(txt), start=1):
+            pass
 
         def marker(m):
             """
@@ -1999,14 +1966,17 @@ class TimeStripper:
             return False
         return True
 
-    def timestripper(self, line):
+    def timestripper(self, line: str) -> Optional['pywikibot.Timestamp']:
         """
         Find timestamp in line and convert it to time zone aware datetime.
 
-        All the following items must be matched, otherwise None is returned:
-        -. year, month, hour, time, day, minute, tzinfo
+        All the following items must be matched, otherwise None is
+        returned: -. year, month, hour, time, day, minute, tzinfo
+
+        .. versionchanged:: 7.6
+           HTML parts are removed from line
+
         :return: A timestamp found on the given line
-        :rtype: pywikibot.Timestamp
         """
         # Try to maintain gaps that are used in _valid_date_dict_positions()
         def censor_match(match):
@@ -2049,6 +2019,7 @@ class TimeStripper:
         # Remove parts that are not supposed to contain the timestamp, in order
         # to reduce false positives.
         line = removeDisabledParts(line)
+        line = removeHTMLParts(line)
 
         line = to_latin_digits(line)
         for pat in self.patterns:
@@ -2106,3 +2077,10 @@ class TimeStripper:
             timestamp = None
 
         return timestamp
+
+
+wrapper = ModuleDeprecationWrapper(__name__)
+wrapper.add_deprecated_attr(
+    'tzoneFixedOffset',
+    replacement_name='pywikibot.time.TZoneFixedOffset',
+    since='7.5.0')
