@@ -5,9 +5,9 @@ decorator functions with function syntax. For example, @deprecated causes
 a different invocation to @deprecated().
 
 The former is invoked with the decorated function as args[0].
-The latter is invoked with the decorator arguments as *args & **kwargs,
-and it must return a callable which will be invoked with the decorated
-function as args[0].
+The latter is invoked with the decorator arguments as ``*args`` &
+``**kwargs``, and it must return a callable which will be invoked with
+the decorated function as args[0].
 
 The follow deprecators may support both syntax, e.g. @deprecated and
 @deprecated() both work. In order to achieve that, the code inspects
@@ -270,9 +270,9 @@ def deprecated(*args, **kwargs):
             if not deprecated_notice.search(wrapper.__doc__):
                 add_docstring(wrapper)
             else:
-                # Get docstring up to @params so deprecation notices for
+                # Get docstring up to :params so deprecation notices for
                 # parameters don't disrupt it
-                trim_params = re.compile(r'^.*?((?=@param)|$)', re.DOTALL)
+                trim_params = re.compile(r'^.*?((?=:param)|$)', re.DOTALL)
                 trimmed_doc = trim_params.match(wrapper.__doc__).group(0)
 
                 if not deprecated_notice.search(trimmed_doc):  # No notice
@@ -500,7 +500,7 @@ def redirect_func(target, source_module: Optional[str] = None,
     parameters.
 
     .. versionchanged:: 7.0
-       `since`parameter must be a release number, not a timestamp.
+       ``since`` parameter must be a release number, not a timestamp.
 
     :param target: The targeted function which is to be executed.
     :type target: callable
@@ -579,7 +579,7 @@ class ModuleDeprecationWrapper(types.ModuleType):
         Add the name to the local deprecated names dict.
 
         .. versionchanged:: 7.0
-           `since`parameter must be a release number, not a timestamp.
+           ``since`` parameter must be a release number, not a timestamp.
 
         :param name: The name of the deprecated class or variable. It may not
             be already deprecated.
