@@ -22,7 +22,8 @@ from pywikibot.bot_choice import (
     StandardOption,
 )
 from pywikibot.logging import INFO, INPUT, STDOUT, VERBOSE, WARNING
-from pywikibot.tools import RLock
+from pywikibot.tools import issue_deprecation_warning
+from pywikibot.tools.threading import RLock
 from pywikibot.userinterfaces import transliteration
 from pywikibot.userinterfaces._interface_base import ABUIC
 
@@ -61,7 +62,7 @@ class UI(ABUIC):
 
     .. versionchanged:: 6.2:
        subclassed from
-       :py:obj:`pywikibot.userinterfaces._interface_base.ABUIC`
+       :py:obj:`userinterfaces._interface_base.ABUIC`
     """
 
     split_col_pat = re.compile(r'(\w+);?(\w+)?')
@@ -201,7 +202,14 @@ class UI(ABUIC):
             raise ValueError('Old color format must not be mixed with new '
                              'color format. Found:\n'
                              + text.replace('\03', '\\03'))
-        text_parts = old_parts if len(old_parts) > 1 else new_parts
+        if len(old_parts) > 1:
+            issue_deprecation_warning(
+                'old color format variant like \03{color}',
+                'new color format like <<color>>',
+                since='7.3.0')
+            text_parts = old_parts
+        else:
+            text_parts = new_parts
         text_parts += ['default']
         # match.split() includes every regex group; for each matched color
         # fg_col:b_col, fg_col and bg_col are added to the resulting list.
@@ -311,9 +319,9 @@ class UI(ABUIC):
                     # could consist of multiple letters.
                     # mark the transliterated letters in yellow.
                     transliteratedText = ''.join((transliteratedText,
-                                                  '\03{lightyellow}',
+                                                  '<<lightyellow>>',
                                                   transliterated,
-                                                  '\03{previous}'))
+                                                  '<<previous>>'))
                     # memorize if we replaced a single letter by multiple
                     # letters.
                     if transliterated:
@@ -352,7 +360,7 @@ class UI(ABUIC):
             an answer.
         :param force: Automatically use the default
         """
-        assert(not password or not default)
+        assert not password or not default
 
         question = question.strip()
         end_marker = question[-1]
@@ -533,7 +541,9 @@ class UI(ABUIC):
 
                 self.stream_output('Error: Invalid response\n')
 
-    def editText(self, text: str, jumpIndex: Optional[int] = None,
+    @staticmethod
+    def editText(text: str,
+                 jumpIndex: Optional[int] = None,
                  highlight: Optional[str] = None) -> Optional[str]:
         """Return the text as edited by the user.
 
