@@ -1,6 +1,6 @@
 """User interface for Unix terminals."""
 #
-# (C) Pywikibot team, 2003-2021
+# (C) Pywikibot team, 2003-2022
 #
 # Distributed under the terms of the MIT license.
 #
@@ -34,16 +34,17 @@ class UnixUI(terminal_interface_base.UI):
 
     """User interface for Unix terminals."""
 
-    def support_color(self, target_stream):
+    def support_color(self, target_stream) -> bool:
         """Return that the target stream supports colors."""
         return True
 
-    def make_unix_bg_color(self, color):
+    @staticmethod
+    def make_unix_bg_color(color):
         """Obtain background color from foreground color."""
         code = re.search(r'(?<=\[)\d+', color).group()
         return chr(27) + '[' + str(int(code) + 10) + 'm'
 
-    def encounter_color(self, color, target_stream):
+    def encounter_color(self, color, target_stream) -> None:
         """Write the Unix color directly to the stream."""
         fg, bg = self.divide_color(color)
         fg = unixColors[fg]
@@ -51,7 +52,3 @@ class UnixUI(terminal_interface_base.UI):
         if bg is not None:
             bg = unixColors[bg]
             self._write(self.make_unix_bg_color(bg), target_stream)
-
-    def _write(self, text, target_stream):
-        """Optionally encode and write the text to the target stream."""
-        target_stream.write(text)
