@@ -1,11 +1,14 @@
-"""
-XML reading module.
+"""XML reading module.
 
 Each XmlEntry object represents a page, as read from an XML source
 
 The XmlDump class reads a pages_current XML dump (like the ones offered on
 https://dumps.wikimedia.org/backup-index.html) and offers a generator over
 XmlEntry objects which can be used by other bots.
+
+.. versionchanged:: 7.7
+   *defusedxml* is used in favour of *xml.etree* if present to prevent
+   vulnerable XML attacks. *defusedxml* 0.7.1 or higher is recommended.
 """
 #
 # (C) Pywikibot team, 2005-2022
@@ -14,7 +17,11 @@ XmlEntry objects which can be used by other bots.
 #
 import re
 from typing import Optional
-from xml.etree.ElementTree import iterparse, ParseError
+
+try:
+    from defusedxml.ElementTree import iterparse, ParseError
+except ImportError:
+    from xml.etree.ElementTree import iterparse, ParseError
 
 from pywikibot.backports import Callable, Type
 from pywikibot.tools import open_archive
@@ -81,7 +88,8 @@ class XmlDump:
     Usage example:
 
     >>> from pywikibot import xmlreader
-    >>> dump = xmlreader.XmlDump('tests/data/xml/article-pear.xml')
+    >>> name = 'tests/data/xml/article-pear.xml'
+    >>> dump = xmlreader.XmlDump(name, allrevisions=True)
     >>> for elem in dump.parse():
     ...     print(elem.title, elem.revisionid)
     ...
